import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';

Vue.use(Router);

const router = new Router({
    routes: [
        {
            path: '/indexview/:indexview?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'indexview';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
            },
            meta: {  
                caption: '流程管理平台',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'indexview', parameterName: 'indexview' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/r7rt-wf/index-view/index-view.vue'),
            children: [
                {
                    path: 'orgs/:org?/gridview/:gridview?',
                    meta: {
                        caption: 'org.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-grid-view/org-grid-view.vue'),
                },
                {
                    path: 'psworkflows/:psworkflow?/psdewfs/:psdewf?/editview/:editview?',
                    meta: {
                        caption: 'psdewf.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psworkflows', parameterName: 'psworkflow' },
                            { pathName: 'psdewfs', parameterName: 'psdewf' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/psdewfedit-view/psdewfedit-view.vue'),
                },
                {
                    path: 'psdewfs/:psdewf?/editview/:editview?',
                    meta: {
                        caption: 'psdewf.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psdewfs', parameterName: 'psdewf' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/psdewfedit-view/psdewfedit-view.vue'),
                },
                {
                    path: 'orgusers/:orguser?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'orguser.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-user-pickup-grid-view/org-user-pickup-grid-view.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'orgdept.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-pickup-grid-view/org-dept-pickup-grid-view.vue'),
                },
                {
                    path: 'orgusers/:orguser?/pickupview/:pickupview?',
                    meta: {
                        caption: 'orguser.views.pickupview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-user-pickup-view/org-user-pickup-view.vue'),
                },
                {
                    path: 'pssystems/:pssystem?/editview/:editview?',
                    meta: {
                        caption: 'pssystem.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pssystems', parameterName: 'pssystem' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pssystem-edit-view/pssystem-edit-view.vue'),
                },
                {
                    path: 'pswfroles/:pswfrole?/pswfroledetails/:pswfroledetail?/editview/:editview?',
                    meta: {
                        caption: 'pswfroledetail.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroles', parameterName: 'pswfrole' },
                            { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-detail-edit-view/pswfrole-detail-edit-view.vue'),
                },
                {
                    path: 'pswfroledetails/:pswfroledetail?/editview/:editview?',
                    meta: {
                        caption: 'pswfroledetail.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-detail-edit-view/pswfrole-detail-edit-view.vue'),
                },
                {
                    path: 'pssystems/:pssystem?/gridview/:gridview?',
                    meta: {
                        caption: 'pssystem.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pssystems', parameterName: 'pssystem' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pssystem-grid-view/pssystem-grid-view.vue'),
                },
                {
                    path: 'orgusers/:orguser?/editview3/:editview3?',
                    meta: {
                        caption: 'orguser.views.editview3.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'editview3', parameterName: 'editview3' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-user-edit-view3/org-user-edit-view3.vue'),
                },
                {
                    path: 'psworkflows/:psworkflow?/editview/:editview?',
                    meta: {
                        caption: 'psworkflow.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psworkflows', parameterName: 'psworkflow' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/psworkflow-edit-view/psworkflow-edit-view.vue'),
                },
                {
                    path: 'wfstepdata/:wfstepdata?/editview/:editview?',
                    meta: {
                        caption: 'wfstepdata.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'wfstepdata', parameterName: 'wfstepdata' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/wfstep-data-edit-view/wfstep-data-edit-view.vue'),
                },
                {
                    path: 'pssysapps/:pssysapp?/editview/:editview?',
                    meta: {
                        caption: 'pssysapp.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pssysapps', parameterName: 'pssysapp' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pssys-app-edit-view/pssys-app-edit-view.vue'),
                },
                {
                    path: 'psworkflows/:psworkflow?/pswfversions/:pswfversion?/editview/:editview?',
                    meta: {
                        caption: 'pswfversion.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psworkflows', parameterName: 'psworkflow' },
                            { pathName: 'pswfversions', parameterName: 'pswfversion' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfversion-edit-view/pswfversion-edit-view.vue'),
                },
                {
                    path: 'pswfversions/:pswfversion?/editview/:editview?',
                    meta: {
                        caption: 'pswfversion.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfversions', parameterName: 'pswfversion' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfversion-edit-view/pswfversion-edit-view.vue'),
                },
                {
                    path: 'pssysapps/:pssysapp?/gridview/:gridview?',
                    meta: {
                        caption: 'pssysapp.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pssysapps', parameterName: 'pssysapp' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pssys-app-grid-view/pssys-app-grid-view.vue'),
                },
                {
                    path: 'pswfroles/:pswfrole?/editview/:editview?',
                    meta: {
                        caption: 'pswfrole.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroles', parameterName: 'pswfrole' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-edit-view/pswfrole-edit-view.vue'),
                },
                {
                    path: 'pswfroles/:pswfrole?/gridview/:gridview?',
                    meta: {
                        caption: 'pswfrole.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroles', parameterName: 'pswfrole' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-grid-view/pswfrole-grid-view.vue'),
                },
                {
                    path: 'orgs/:org?/editview/:editview?',
                    meta: {
                        caption: 'org.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-edit-view/org-edit-view.vue'),
                },
                {
                    path: 'wfapps/:wfapp?/editview/:editview?',
                    meta: {
                        caption: 'wfapp.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'wfapps', parameterName: 'wfapp' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/wfapp-edit-view/wfapp-edit-view.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/gridview/:gridview?',
                    meta: {
                        caption: 'orgdept.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-grid-view/org-dept-grid-view.vue'),
                },
                {
                    path: 'wfstepdata/:wfstepdata?/gridview/:gridview?',
                    meta: {
                        caption: 'wfstepdata.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'wfstepdata', parameterName: 'wfstepdata' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/wfstep-data-grid-view/wfstep-data-grid-view.vue'),
                },
                {
                    path: 'wfinstances/:wfinstance?/gridview/:gridview?',
                    meta: {
                        caption: 'wfinstance.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'wfinstances', parameterName: 'wfinstance' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/wfinstance-grid-view/wfinstance-grid-view.vue'),
                },
                {
                    path: 'wfapps/:wfapp?/gridview/:gridview?',
                    meta: {
                        caption: 'wfapp.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'wfapps', parameterName: 'wfapp' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/wfapp-grid-view/wfapp-grid-view.vue'),
                },
                {
                    path: 'psworkflows/:psworkflow?/gridview/:gridview?',
                    meta: {
                        caption: 'psworkflow.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psworkflows', parameterName: 'psworkflow' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/psworkflow-grid-view/psworkflow-grid-view.vue'),
                },
                {
                    path: 'orgs/:org?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'org.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-pickup-grid-view/org-pickup-grid-view.vue'),
                },
                {
                    path: 'psworkflows/:psworkflow?/psdewfs/:psdewf?/gridview/:gridview?',
                    meta: {
                        caption: 'psdewf.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psworkflows', parameterName: 'psworkflow' },
                            { pathName: 'psdewfs', parameterName: 'psdewf' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/psdewfgrid-view/psdewfgrid-view.vue'),
                },
                {
                    path: 'psdewfs/:psdewf?/gridview/:gridview?',
                    meta: {
                        caption: 'psdewf.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psdewfs', parameterName: 'psdewf' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/psdewfgrid-view/psdewfgrid-view.vue'),
                },
                {
                    path: 'orgdeptusers/:orgdeptuser?/editview/:editview?',
                    meta: {
                        caption: 'orgdeptuser.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-user-edit-view/org-dept-user-edit-view.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/pickupview/:pickupview?',
                    meta: {
                        caption: 'orgdept.views.pickupview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-pickup-view/org-dept-pickup-view.vue'),
                },
                {
                    path: 'orgs/:org?/pickupview/:pickupview?',
                    meta: {
                        caption: 'org.views.pickupview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-pickup-view/org-pickup-view.vue'),
                },
                {
                    path: 'wfworklists/:wfworklist?/gridview/:gridview?',
                    meta: {
                        caption: 'wfworklist.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'wfworklists', parameterName: 'wfworklist' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/wfworklist-grid-view/wfworklist-grid-view.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/editview/:editview?',
                    meta: {
                        caption: 'orgdept.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-edit-view/org-dept-edit-view.vue'),
                },
                {
                    path: 'orgusers/:orguser?/gridview/:gridview?',
                    meta: {
                        caption: 'orguser.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-user-grid-view/org-user-grid-view.vue'),
                },
                {
                    path: 'pswfroles/:pswfrole?/pswfroledetails/:pswfroledetail?/gridview/:gridview?',
                    meta: {
                        caption: 'pswfroledetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroles', parameterName: 'pswfrole' },
                            { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-detail-grid-view/pswfrole-detail-grid-view.vue'),
                },
                {
                    path: 'pswfroledetails/:pswfroledetail?/gridview/:gridview?',
                    meta: {
                        caption: 'pswfroledetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-detail-grid-view/pswfrole-detail-grid-view.vue'),
                },
                {
                    path: 'orgdeptusers/:orgdeptuser?/gridview/:gridview?',
                    meta: {
                        caption: 'orgdeptuser.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-user-grid-view/org-dept-user-grid-view.vue'),
                },
                {
                    path: 'wfinstances/:wfinstance?/editview/:editview?',
                    meta: {
                        caption: 'wfinstance.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'wfinstances', parameterName: 'wfinstance' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/wfinstance-edit-view/wfinstance-edit-view.vue'),
                },
                {
                    path: 'wfworklists/:wfworklist?/editview/:editview?',
                    meta: {
                        caption: 'wfworklist.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'wfworklists', parameterName: 'wfworklist' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/wfworklist-edit-view/wfworklist-edit-view.vue'),
                },
                {
                    path: 'psworkflows/:psworkflow?/pswfversions/:pswfversion?/gridview/:gridview?',
                    meta: {
                        caption: 'pswfversion.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psworkflows', parameterName: 'psworkflow' },
                            { pathName: 'pswfversions', parameterName: 'pswfversion' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfversion-grid-view/pswfversion-grid-view.vue'),
                },
                {
                    path: 'pswfversions/:pswfversion?/gridview/:gridview?',
                    meta: {
                        caption: 'pswfversion.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfversions', parameterName: 'pswfversion' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfversion-grid-view/pswfversion-grid-view.vue'),
                },
            {
                path: 'dewfdataredirectview/:dewfdataredirectview?',
                meta: {
                    caption: 'wfworklist.views.wfdataredirectview.caption',
                    parameters: [
                        { pathName: 'wfworklistwfdataredirectview', parameterName: 'wfworklistwfdataredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/r7rt-wf/wfworklist-wfdata-redirect-view/wfworklist-wfdata-redirect-view.vue'),
            },
            ],
        },
    {
        path: '/wfapps/:wfapp?/gridview/:gridview?',
        meta: {
            caption: 'wfapp.views.gridview.caption',
            parameters: [
                { pathName: 'wfapps', parameterName: 'wfapp' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfapp-grid-view/wfapp-grid-view.vue'),
    },
    {
        path: '/wfinstances/:wfinstance?/gridview/:gridview?',
        meta: {
            caption: 'wfinstance.views.gridview.caption',
            parameters: [
                { pathName: 'wfinstances', parameterName: 'wfinstance' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfinstance-grid-view/wfinstance-grid-view.vue'),
    },
    {
        path: '/psworkflows/:psworkflow?/psdewfs/:psdewf?/gridview/:gridview?',
        meta: {
            caption: 'psdewf.views.gridview.caption',
            parameters: [
                { pathName: 'psworkflows', parameterName: 'psworkflow' },
                { pathName: 'psdewfs', parameterName: 'psdewf' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/psdewfgrid-view/psdewfgrid-view.vue'),
    },
    {
        path: '/psdewfs/:psdewf?/gridview/:gridview?',
        meta: {
            caption: 'psdewf.views.gridview.caption',
            parameters: [
                { pathName: 'psdewfs', parameterName: 'psdewf' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/psdewfgrid-view/psdewfgrid-view.vue'),
    },
    {
        path: '/pssysapps/:pssysapp?/gridview/:gridview?',
        meta: {
            caption: 'pssysapp.views.gridview.caption',
            parameters: [
                { pathName: 'pssysapps', parameterName: 'pssysapp' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pssys-app-grid-view/pssys-app-grid-view.vue'),
    },
    {
        path: '/wfstepdata/:wfstepdata?/editview/:editview?',
        meta: {
            caption: 'wfstepdata.views.editview.caption',
            parameters: [
                { pathName: 'wfstepdata', parameterName: 'wfstepdata' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfstep-data-edit-view/wfstep-data-edit-view.vue'),
    },
    {
        path: '/pswfroles/:pswfrole?/editview/:editview?',
        meta: {
            caption: 'pswfrole.views.editview.caption',
            parameters: [
                { pathName: 'pswfroles', parameterName: 'pswfrole' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-edit-view/pswfrole-edit-view.vue'),
    },
    {
        path: '/orgdeptusers/:orgdeptuser?/gridview/:gridview?',
        meta: {
            caption: 'orgdeptuser.views.gridview.caption',
            parameters: [
                { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-user-grid-view/org-dept-user-grid-view.vue'),
    },
    {
        path: '/orgs/:org?/gridview/:gridview?',
        meta: {
            caption: 'org.views.gridview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-grid-view/org-grid-view.vue'),
    },
    {
        path: '/pssysapps/:pssysapp?/editview/:editview?',
        meta: {
            caption: 'pssysapp.views.editview.caption',
            parameters: [
                { pathName: 'pssysapps', parameterName: 'pssysapp' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pssys-app-edit-view/pssys-app-edit-view.vue'),
    },
    {
        path: '/orgdeptusers/:orgdeptuser?/editview/:editview?',
        meta: {
            caption: 'orgdeptuser.views.editview.caption',
            parameters: [
                { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-user-edit-view/org-dept-user-edit-view.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/pickupview/:pickupview?',
        meta: {
            caption: 'orgdept.views.pickupview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-pickup-view/org-dept-pickup-view.vue'),
    },
    {
        path: '/pswfroles/:pswfrole?/gridview/:gridview?',
        meta: {
            caption: 'pswfrole.views.gridview.caption',
            parameters: [
                { pathName: 'pswfroles', parameterName: 'pswfrole' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-grid-view/pswfrole-grid-view.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/gridview/:gridview?',
        meta: {
            caption: 'orgdept.views.gridview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-grid-view/org-dept-grid-view.vue'),
    },
    {
        path: '/pswfroles/:pswfrole?/pswfroledetails/:pswfroledetail?/gridview/:gridview?',
        meta: {
            caption: 'pswfroledetail.views.gridview.caption',
            parameters: [
                { pathName: 'pswfroles', parameterName: 'pswfrole' },
                { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-detail-grid-view/pswfrole-detail-grid-view.vue'),
    },
    {
        path: '/pswfroledetails/:pswfroledetail?/gridview/:gridview?',
        meta: {
            caption: 'pswfroledetail.views.gridview.caption',
            parameters: [
                { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-detail-grid-view/pswfrole-detail-grid-view.vue'),
    },
    {
        path: '/wfapps/:wfapp?/editview/:editview?',
        meta: {
            caption: 'wfapp.views.editview.caption',
            parameters: [
                { pathName: 'wfapps', parameterName: 'wfapp' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfapp-edit-view/wfapp-edit-view.vue'),
    },
    {
        path: '/orgusers/:orguser?/pickupview/:pickupview?',
        meta: {
            caption: 'orguser.views.pickupview.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-user-pickup-view/org-user-pickup-view.vue'),
    },
    {
        path: '/psworkflows/:psworkflow?/pswfversions/:pswfversion?/editview/:editview?',
        meta: {
            caption: 'pswfversion.views.editview.caption',
            parameters: [
                { pathName: 'psworkflows', parameterName: 'psworkflow' },
                { pathName: 'pswfversions', parameterName: 'pswfversion' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfversion-edit-view/pswfversion-edit-view.vue'),
    },
    {
        path: '/pswfversions/:pswfversion?/editview/:editview?',
        meta: {
            caption: 'pswfversion.views.editview.caption',
            parameters: [
                { pathName: 'pswfversions', parameterName: 'pswfversion' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfversion-edit-view/pswfversion-edit-view.vue'),
    },
    {
        path: '/psworkflows/:psworkflow?/pswfversions/:pswfversion?/gridview/:gridview?',
        meta: {
            caption: 'pswfversion.views.gridview.caption',
            parameters: [
                { pathName: 'psworkflows', parameterName: 'psworkflow' },
                { pathName: 'pswfversions', parameterName: 'pswfversion' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfversion-grid-view/pswfversion-grid-view.vue'),
    },
    {
        path: '/pswfversions/:pswfversion?/gridview/:gridview?',
        meta: {
            caption: 'pswfversion.views.gridview.caption',
            parameters: [
                { pathName: 'pswfversions', parameterName: 'pswfversion' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfversion-grid-view/pswfversion-grid-view.vue'),
    },
    {
        path: '/orgusers/:orguser?/editview3/:editview3?',
        meta: {
            caption: 'orguser.views.editview3.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'editview3', parameterName: 'editview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-user-edit-view3/org-user-edit-view3.vue'),
    },
    {
        path: '/pssystems/:pssystem?/editview/:editview?',
        meta: {
            caption: 'pssystem.views.editview.caption',
            parameters: [
                { pathName: 'pssystems', parameterName: 'pssystem' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pssystem-edit-view/pssystem-edit-view.vue'),
    },
    {
        path: '/orgs/:org?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'org.views.pickupgridview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-pickup-grid-view/org-pickup-grid-view.vue'),
    },
    {
        path: '/psworkflows/:psworkflow?/psdewfs/:psdewf?/editview/:editview?',
        meta: {
            caption: 'psdewf.views.editview.caption',
            parameters: [
                { pathName: 'psworkflows', parameterName: 'psworkflow' },
                { pathName: 'psdewfs', parameterName: 'psdewf' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/psdewfedit-view/psdewfedit-view.vue'),
    },
    {
        path: '/psdewfs/:psdewf?/editview/:editview?',
        meta: {
            caption: 'psdewf.views.editview.caption',
            parameters: [
                { pathName: 'psdewfs', parameterName: 'psdewf' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/psdewfedit-view/psdewfedit-view.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'orgdept.views.pickupgridview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-pickup-grid-view/org-dept-pickup-grid-view.vue'),
    },
    {
        path: '/psworkflows/:psworkflow?/gridview/:gridview?',
        meta: {
            caption: 'psworkflow.views.gridview.caption',
            parameters: [
                { pathName: 'psworkflows', parameterName: 'psworkflow' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/psworkflow-grid-view/psworkflow-grid-view.vue'),
    },
    {
        path: '/orgusers/:orguser?/gridview/:gridview?',
        meta: {
            caption: 'orguser.views.gridview.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-user-grid-view/org-user-grid-view.vue'),
    },
    {
        path: '/orgusers/:orguser?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'orguser.views.pickupgridview.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-user-pickup-grid-view/org-user-pickup-grid-view.vue'),
    },
    {
        path: '/wfworklists/:wfworklist?/editview/:editview?',
        meta: {
            caption: 'wfworklist.views.editview.caption',
            parameters: [
                { pathName: 'wfworklists', parameterName: 'wfworklist' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfworklist-edit-view/wfworklist-edit-view.vue'),
    },
    {
        path: '/orgs/:org?/pickupview/:pickupview?',
        meta: {
            caption: 'org.views.pickupview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-pickup-view/org-pickup-view.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/editview/:editview?',
        meta: {
            caption: 'orgdept.views.editview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-edit-view/org-dept-edit-view.vue'),
    },
    {
        path: '/orgs/:org?/editview/:editview?',
        meta: {
            caption: 'org.views.editview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-edit-view/org-edit-view.vue'),
    },
    {
        path: '/wfstepdata/:wfstepdata?/gridview/:gridview?',
        meta: {
            caption: 'wfstepdata.views.gridview.caption',
            parameters: [
                { pathName: 'wfstepdata', parameterName: 'wfstepdata' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfstep-data-grid-view/wfstep-data-grid-view.vue'),
    },
    {
        path: '/psworkflows/:psworkflow?/editview/:editview?',
        meta: {
            caption: 'psworkflow.views.editview.caption',
            parameters: [
                { pathName: 'psworkflows', parameterName: 'psworkflow' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/psworkflow-edit-view/psworkflow-edit-view.vue'),
    },
    {
        path: '/pswfroles/:pswfrole?/pswfroledetails/:pswfroledetail?/editview/:editview?',
        meta: {
            caption: 'pswfroledetail.views.editview.caption',
            parameters: [
                { pathName: 'pswfroles', parameterName: 'pswfrole' },
                { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-detail-edit-view/pswfrole-detail-edit-view.vue'),
    },
    {
        path: '/pswfroledetails/:pswfroledetail?/editview/:editview?',
        meta: {
            caption: 'pswfroledetail.views.editview.caption',
            parameters: [
                { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-detail-edit-view/pswfrole-detail-edit-view.vue'),
    },
    {
        path: '/wfworklists/:wfworklist?/gridview/:gridview?',
        meta: {
            caption: 'wfworklist.views.gridview.caption',
            parameters: [
                { pathName: 'wfworklists', parameterName: 'wfworklist' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfworklist-grid-view/wfworklist-grid-view.vue'),
    },
    {
        path: '/wfinstances/:wfinstance?/editview/:editview?',
        meta: {
            caption: 'wfinstance.views.editview.caption',
            parameters: [
                { pathName: 'wfinstances', parameterName: 'wfinstance' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfinstance-edit-view/wfinstance-edit-view.vue'),
    },
            {
                path: '/dewfdataredirectview/:dewfdataredirectview?',
                meta: {
                    caption: 'wfworklist.views.wfdataredirectview.caption',
                    parameters: [
                        { pathName: 'wfworklistwfdataredirectview', parameterName: 'wfworklistwfdataredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/r7rt-wf/wfworklist-wfdata-redirect-view/wfworklist-wfdata-redirect-view.vue'),
            },
    {
        path: '/pssystems/:pssystem?/gridview/:gridview?',
        meta: {
            caption: 'pssystem.views.gridview.caption',
            parameters: [
                { pathName: 'pssystems', parameterName: 'pssystem' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pssystem-grid-view/pssystem-grid-view.vue'),
    },
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                router.app.$store.commit('resetRootStateData');
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'indexview'
        },
    ],
});

export default router;
