/**
 * 实体数据服务注册中心
 *
 * @export
 * @class EntityServiceRegister
 */
export class EntityServiceRegister {

    /**
     * 所有实体数据服务Map
     *
     * @protected
     * @type {*}
     * @memberof EntityServiceRegister
     */
    protected allEntityService: Map<string, () => Promise<any>> = new Map();

    /**
     * 已加载实体数据服务Map缓存
     *
     * @protected
     * @type {Map<string, any>}
     * @memberof EntityServiceRegister
     */
    protected serviceCache: Map<string, any> = new Map();

    /**
     * Creates an instance of EntityServiceRegister.
     * @memberof EntityServiceRegister
     */
    constructor() {
        this.init();
    }

    /**
     * 初始化
     *
     * @protected
     * @memberof EntityServiceRegister
     */
    protected init(): void {
                this.allEntityService.set('entity', () => import('@/service/entity/entity-service'));
        this.allEntityService.set('wfuser', () => import('@/service/wfuser/wfuser-service'));
        this.allEntityService.set('psdataentity', () => import('@/service/psdata-entity/psdata-entity-service'));
        this.allEntityService.set('wfstepdata', () => import('@/service/wfstep-data/wfstep-data-service'));
        this.allEntityService.set('orgdept', () => import('@/service/org-dept/org-dept-service'));
        this.allEntityService.set('pswfversion', () => import('@/service/pswfversion/pswfversion-service'));
        this.allEntityService.set('pssystem', () => import('@/service/pssystem/pssystem-service'));
        this.allEntityService.set('pswfprocrole', () => import('@/service/pswfproc-role/pswfproc-role-service'));
        this.allEntityService.set('orguser', () => import('@/service/org-user/org-user-service'));
        this.allEntityService.set('pswfprocess', () => import('@/service/pswfprocess/pswfprocess-service'));
        this.allEntityService.set('wfapp', () => import('@/service/wfapp/wfapp-service'));
        this.allEntityService.set('pswfrole', () => import('@/service/pswfrole/pswfrole-service'));
        this.allEntityService.set('pswflink', () => import('@/service/pswflink/pswflink-service'));
        this.allEntityService.set('wfengine', () => import('@/service/wfengine/wfengine-service'));
        this.allEntityService.set('pswfprocsubwf', () => import('@/service/pswfprocsubwf/pswfprocsubwf-service'));
        this.allEntityService.set('psdewf', () => import('@/service/psdewf/psdewf-service'));
        this.allEntityService.set('wfmode', () => import('@/service/wfmode/wfmode-service'));
        this.allEntityService.set('wfrole', () => import('@/service/wfrole/wfrole-service'));
        this.allEntityService.set('orgdeptuser', () => import('@/service/org-dept-user/org-dept-user-service'));
        this.allEntityService.set('orgdeptwfver', () => import('@/service/org-dept-wfver/org-dept-wfver-service'));
        this.allEntityService.set('psworkflow', () => import('@/service/psworkflow/psworkflow-service'));
        this.allEntityService.set('pssyswfcat', () => import('@/service/pssys-wfcat/pssys-wfcat-service'));
        this.allEntityService.set('workflow', () => import('@/service/workflow/workflow-service'));
        this.allEntityService.set('org', () => import('@/service/org/org-service'));
        this.allEntityService.set('wfstep', () => import('@/service/wfstep/wfstep-service'));
        this.allEntityService.set('wfworklist', () => import('@/service/wfworklist/wfworklist-service'));
        this.allEntityService.set('pswfroledetail', () => import('@/service/pswfrole-detail/pswfrole-detail-service'));
        this.allEntityService.set('wfiaaction', () => import('@/service/wfiaaction/wfiaaction-service'));
        this.allEntityService.set('wfinstance', () => import('@/service/wfinstance/wfinstance-service'));
        this.allEntityService.set('pssysapp', () => import('@/service/pssys-app/pssys-app-service'));
        this.allEntityService.set('wfstepactor', () => import('@/service/wfstep-actor/wfstep-actor-service'));
    }

    /**
     * 加载实体数据服务
     *
     * @protected
     * @param {string} serviceName
     * @returns {Promise<any>}
     * @memberof EntityServiceRegister
     */
    protected async loadService(serviceName: string): Promise<any> {
        const service = this.allEntityService.get(serviceName);
        if (service) {
            return service();
        }
    }

    /**
     * 获取应用实体数据服务
     *
     * @param {string} name
     * @returns {Promise<any>}
     * @memberof EntityServiceRegister
     */
    public async getService(name: string): Promise<any> {
        if (this.serviceCache.has(name)) {
            return this.serviceCache.get(name);
        }
        const entityService: any = await this.loadService(name);
        if (entityService && entityService.default) {
            const instance: any = new entityService.default();
            this.serviceCache.set(name, instance);
            return instance;
        }
    }

}
export const entityServiceRegister: EntityServiceRegister = new EntityServiceRegister();