import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 业务实体工作流服务对象基类
 *
 * @export
 * @class PSDEWFServiceBase
 * @extends {EntityServie}
 */
export default class PSDEWFServiceBase extends EntityService {

    /**
     * Creates an instance of  PSDEWFServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  PSDEWFServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof PSDEWFServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='psdewf';
        this.APPDEKEY = 'psdewfid';
        this.APPDENAME = 'psdewfs';
        this.APPDETEXT = 'psdewfname';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSDEWFServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.psdewf){
            return Http.getInstance().get(`/psworkflows/${context.psworkflow}/psdewfs/${context.psdewf}/select`,isloading);
        }
            return Http.getInstance().get(`/psdewfs/${context.psdewf}/select`,isloading);
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSDEWFServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && true){
            return Http.getInstance().get(`/psworkflows/${context.psworkflow}/psdewfs/getdraft`,isloading);
        }
        let res:any = await  Http.getInstance().get(`/psdewfs/getdraft`,isloading);
        res.data.psdewf = data.psdewf;
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSDEWFServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.psdewf){
            return Http.getInstance().put(`/psworkflows/${context.psworkflow}/psdewfs/${context.psdewf}`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/psdewfs/${context.psdewf}`,data,isloading);
            return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSDEWFServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.psdewf){
            return Http.getInstance().post(`/psworkflows/${context.psworkflow}/psdewfs/${context.psdewf}/checkkey`,data,isloading);
        }
            return Http.getInstance().post(`/psdewfs/${context.psdewf}/checkkey`,data,isloading);
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSDEWFServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.psdewf){
            return Http.getInstance().get(`/psworkflows/${context.psworkflow}/psdewfs/${context.psdewf}`,isloading);
        }
            let res:any = await Http.getInstance().get(`/psdewfs/${context.psdewf}`,isloading);
            return res;

    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSDEWFServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && true){
            data[this.APPDEKEY] = null;
            return Http.getInstance().post(`/psworkflows/${context.psworkflow}/psdewfs`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        data[this.APPDEKEY] = null;
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/psdewfs`,data,isloading);
        return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSDEWFServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.psdewf){
            return Http.getInstance().delete(`/psworkflows/${context.psworkflow}/psdewfs/${context.psdewf}`,isloading);
        }
            return Http.getInstance().delete(`/psdewfs/${context.psdewf}`,isloading);

    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSDEWFServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.psdewf){
            return Http.getInstance().post(`/psworkflows/${context.psworkflow}/psdewfs/${context.psdewf}/save`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/psdewfs/${context.psdewf}/save`,data,isloading);
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSDEWFServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/psworkflows/${context.psworkflow}/psdewfs/fetchdefault`,tempData,isloading);
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/psdewfs/fetchdefault`,tempData,isloading);
    }
}