import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 业务流程版本服务对象基类
 *
 * @export
 * @class PSWFVersionServiceBase
 * @extends {EntityServie}
 */
export default class PSWFVersionServiceBase extends EntityService {

    /**
     * Creates an instance of  PSWFVersionServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  PSWFVersionServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof PSWFVersionServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='pswfversion';
        this.APPDEKEY = 'pswfversionid';
        this.APPDENAME = 'pswfversions';
        this.APPDETEXT = 'pswfversionname';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFVersionServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.pswfversion){
            return Http.getInstance().get(`/psworkflows/${context.psworkflow}/pswfversions/${context.pswfversion}/select`,isloading);
        }
            return Http.getInstance().get(`/pswfversions/${context.pswfversion}/select`,isloading);
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFVersionServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.pswfversion){
            return Http.getInstance().post(`/psworkflows/${context.psworkflow}/pswfversions/${context.pswfversion}/checkkey`,data,isloading);
        }
            return Http.getInstance().post(`/pswfversions/${context.pswfversion}/checkkey`,data,isloading);
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFVersionServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && true){
            return Http.getInstance().get(`/psworkflows/${context.psworkflow}/pswfversions/getdraft`,isloading);
        }
        let res:any = await  Http.getInstance().get(`/pswfversions/getdraft`,isloading);
        res.data.pswfversion = data.pswfversion;
        return res;
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFVersionServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.pswfversion){
            return Http.getInstance().put(`/psworkflows/${context.psworkflow}/pswfversions/${context.pswfversion}`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/pswfversions/${context.pswfversion}`,data,isloading);
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFVersionServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.pswfversion){
            return Http.getInstance().get(`/psworkflows/${context.psworkflow}/pswfversions/${context.pswfversion}`,isloading);
        }
            let res:any = await Http.getInstance().get(`/pswfversions/${context.pswfversion}`,isloading);
            return res;

    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFVersionServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && true){
            data[this.APPDEKEY] = null;
            return Http.getInstance().post(`/psworkflows/${context.psworkflow}/pswfversions`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
        data[this.APPDEKEY] = null;
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/pswfversions`,data,isloading);
        return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFVersionServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.pswfversion){
            return Http.getInstance().delete(`/psworkflows/${context.psworkflow}/pswfversions/${context.pswfversion}`,isloading);
        }
            return Http.getInstance().delete(`/pswfversions/${context.pswfversion}`,isloading);

    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFVersionServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && context.pswfversion){
            return Http.getInstance().post(`/psworkflows/${context.psworkflow}/pswfversions/${context.pswfversion}/save`,data,isloading);
        }
        let masterData:any = {};
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/pswfversions/${context.pswfversion}/save`,data,isloading);
            return res;
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFVersionServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        if(context.psworkflow && true){
            let tempData:any = JSON.parse(JSON.stringify(data));
            return Http.getInstance().get(`/psworkflows/${context.psworkflow}/pswfversions/fetchdefault`,tempData,isloading);
        }
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pswfversions/fetchdefault`,tempData,isloading);
    }
}