/**
 * UI服务注册中心
 *
 * @export
 * @class UIServiceRegister
 */
export class UIServiceRegister {

    /**
     * 所有UI实体服务Map
     *
     * @protected
     * @type {*}
     * @memberof UIServiceRegister
     */
    protected allUIService: Map<string, () => Promise<any>> = new Map();

    /**
     * 已加载UI实体服务Map缓存
     *
     * @protected
     * @type {Map<string, any>}
     * @memberof UIServiceRegister
     */
    protected serviceCache: Map<string, any> = new Map();

    /**
     * Creates an instance of UIServiceRegister.
     * @memberof UIServiceRegister
     */
    constructor() {
        this.init();
    }

    /**
     * 初始化
     *
     * @protected
     * @memberof UIServiceRegister
     */
    protected init(): void {
                this.allUIService.set('entity', () => import('@/uiservice/entity/entity-ui-service'));
        this.allUIService.set('wfuser', () => import('@/uiservice/wfuser/wfuser-ui-service'));
        this.allUIService.set('psdataentity', () => import('@/uiservice/psdata-entity/psdata-entity-ui-service'));
        this.allUIService.set('wfstepdata', () => import('@/uiservice/wfstep-data/wfstep-data-ui-service'));
        this.allUIService.set('orgdept', () => import('@/uiservice/org-dept/org-dept-ui-service'));
        this.allUIService.set('pswfversion', () => import('@/uiservice/pswfversion/pswfversion-ui-service'));
        this.allUIService.set('pssystem', () => import('@/uiservice/pssystem/pssystem-ui-service'));
        this.allUIService.set('pswfprocrole', () => import('@/uiservice/pswfproc-role/pswfproc-role-ui-service'));
        this.allUIService.set('orguser', () => import('@/uiservice/org-user/org-user-ui-service'));
        this.allUIService.set('pswfprocess', () => import('@/uiservice/pswfprocess/pswfprocess-ui-service'));
        this.allUIService.set('wfapp', () => import('@/uiservice/wfapp/wfapp-ui-service'));
        this.allUIService.set('pswfrole', () => import('@/uiservice/pswfrole/pswfrole-ui-service'));
        this.allUIService.set('pswflink', () => import('@/uiservice/pswflink/pswflink-ui-service'));
        this.allUIService.set('wfengine', () => import('@/uiservice/wfengine/wfengine-ui-service'));
        this.allUIService.set('pswfprocsubwf', () => import('@/uiservice/pswfprocsubwf/pswfprocsubwf-ui-service'));
        this.allUIService.set('psdewf', () => import('@/uiservice/psdewf/psdewf-ui-service'));
        this.allUIService.set('wfmode', () => import('@/uiservice/wfmode/wfmode-ui-service'));
        this.allUIService.set('wfrole', () => import('@/uiservice/wfrole/wfrole-ui-service'));
        this.allUIService.set('orgdeptuser', () => import('@/uiservice/org-dept-user/org-dept-user-ui-service'));
        this.allUIService.set('orgdeptwfver', () => import('@/uiservice/org-dept-wfver/org-dept-wfver-ui-service'));
        this.allUIService.set('psworkflow', () => import('@/uiservice/psworkflow/psworkflow-ui-service'));
        this.allUIService.set('pssyswfcat', () => import('@/uiservice/pssys-wfcat/pssys-wfcat-ui-service'));
        this.allUIService.set('workflow', () => import('@/uiservice/workflow/workflow-ui-service'));
        this.allUIService.set('org', () => import('@/uiservice/org/org-ui-service'));
        this.allUIService.set('wfstep', () => import('@/uiservice/wfstep/wfstep-ui-service'));
        this.allUIService.set('wfworklist', () => import('@/uiservice/wfworklist/wfworklist-ui-service'));
        this.allUIService.set('pswfroledetail', () => import('@/uiservice/pswfrole-detail/pswfrole-detail-ui-service'));
        this.allUIService.set('wfiaaction', () => import('@/uiservice/wfiaaction/wfiaaction-ui-service'));
        this.allUIService.set('wfinstance', () => import('@/uiservice/wfinstance/wfinstance-ui-service'));
        this.allUIService.set('pssysapp', () => import('@/uiservice/pssys-app/pssys-app-ui-service'));
        this.allUIService.set('wfstepactor', () => import('@/uiservice/wfstep-actor/wfstep-actor-ui-service'));
    }

    /**
     * 加载服务实体
     *
     * @protected
     * @param {string} serviceName
     * @returns {Promise<any>}
     * @memberof UIServiceRegister
     */
    protected async loadService(serviceName: string): Promise<any> {
        const service = this.allUIService.get(serviceName);
        if (service) {
            return service();
        }
    }

    /**
     * 获取应用实体服务
     *
     * @param {string} name
     * @returns {Promise<any>}
     * @memberof UIServiceRegister
     */
    public async getService(name: string): Promise<any> {
        if (this.serviceCache.has(name)) {
            return this.serviceCache.get(name);
        }
        const entityService: any = await this.loadService(name);
        if (entityService && entityService.default) {
            const instance: any = new entityService.default();
            this.serviceCache.set(name, instance);
            return instance;
        }
    }

}
export const uiServiceRegister: UIServiceRegister = new UIServiceRegister();