import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';

Vue.use(Router);

const router = new Router({
    routes: [
        {
            path: '/indexview/:indexview?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'indexview';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
            },
            meta: {  
                caption: '统一待办门户',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'indexview', parameterName: 'indexview' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/r7rt-wf/index-view/index-view.vue'),
            children: [
                {
                    path: 'wfworklists/:wfworklist?/todogridview/:todogridview?',
                    meta: {
                        caption: 'wfworklist.views.todogridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'wfworklists', parameterName: 'wfworklist' },
                            { pathName: 'todogridview', parameterName: 'todogridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/wfworklist-todo-grid-view/wfworklist-todo-grid-view.vue'),
                },
                {
                    path: 'wfworklists/:wfworklist?/donegridview/:donegridview?',
                    meta: {
                        caption: 'wfworklist.views.donegridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'wfworklists', parameterName: 'wfworklist' },
                            { pathName: 'donegridview', parameterName: 'donegridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/wfworklist-done-grid-view/wfworklist-done-grid-view.vue'),
                },
                {
                    path: 'wfworklists/:wfworklist?/editview/:editview?',
                    meta: {
                        caption: 'wfworklist.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'wfworklists', parameterName: 'wfworklist' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/wfworklist-edit-view/wfworklist-edit-view.vue'),
                },
            {
                path: 'dewfdataredirectview/:dewfdataredirectview?',
                meta: {
                    caption: 'wfworklist.views.wfdataredirectview.caption',
                    parameters: [
                        { pathName: 'wfworklistwfdataredirectview', parameterName: 'wfworklistwfdataredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/r7rt-wf/wfworklist-wfdata-redirect-view/wfworklist-wfdata-redirect-view.vue'),
            },
            ],
        },
    {
        path: '/wfworklists/:wfworklist?/todogridview/:todogridview?',
        meta: {
            caption: 'wfworklist.views.todogridview.caption',
            parameters: [
                { pathName: 'wfworklists', parameterName: 'wfworklist' },
                { pathName: 'todogridview', parameterName: 'todogridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfworklist-todo-grid-view/wfworklist-todo-grid-view.vue'),
    },
    {
        path: '/wfworklists/:wfworklist?/editview/:editview?',
        meta: {
            caption: 'wfworklist.views.editview.caption',
            parameters: [
                { pathName: 'wfworklists', parameterName: 'wfworklist' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfworklist-edit-view/wfworklist-edit-view.vue'),
    },
    {
        path: '/wfworklists/:wfworklist?/donegridview/:donegridview?',
        meta: {
            caption: 'wfworklist.views.donegridview.caption',
            parameters: [
                { pathName: 'wfworklists', parameterName: 'wfworklist' },
                { pathName: 'donegridview', parameterName: 'donegridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/wfworklist-done-grid-view/wfworklist-done-grid-view.vue'),
    },
            {
                path: '/dewfdataredirectview/:dewfdataredirectview?',
                meta: {
                    caption: 'wfworklist.views.wfdataredirectview.caption',
                    parameters: [
                        { pathName: 'wfworklistwfdataredirectview', parameterName: 'wfworklistwfdataredirectview' },
                    ],
                    requireAuth: true,
                },
                component: () => import('@pages/r7rt-wf/wfworklist-wfdata-redirect-view/wfworklist-wfdata-redirect-view.vue'),
            },
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                router.app.$store.commit('resetRootStateData');
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'indexview'
        },
    ],
});

export default router;
