import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';

Vue.use(Router);

const router = new Router({
    routes: [
        {
            path: '/selectindexview/:selectindexview?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'selectindexview';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
            },
            meta: {  
                caption: '流程选择',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'selectindexview', parameterName: 'selectindexview' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/wf/select-index-view/select-index-view.vue'),
            children: [
                {
                    path: 'pswfversions/:pswfversion?/dataview/:dataview?',
                    meta: {
                        caption: 'pswfversion.views.dataview.caption',
                        parameters: [
                            { pathName: 'selectindexview', parameterName: 'selectindexview' },
                            { pathName: 'pswfversions', parameterName: 'pswfversion' },
                            { pathName: 'dataview', parameterName: 'dataview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/wf/pswfversiondata-view/pswfversiondata-view.vue'),
                },
            ],
        },
    {
        path: '/pswfversions/:pswfversion?/dataview/:dataview?',
        meta: {
            caption: 'pswfversion.views.dataview.caption',
            parameters: [
                { pathName: 'pswfversions', parameterName: 'pswfversion' },
                { pathName: 'dataview', parameterName: 'dataview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/wf/pswfversiondata-view/pswfversiondata-view.vue'),
    },
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                router.app.$store.commit('resetRootStateData');
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'selectindexview'
        },
    ],
});

export default router;
