import { Http,Util,Errorlog } from '@/utils';
import ControlService from '@/widgets/control-service';
import PSWFVersionService from '@/service/pswfversion/pswfversion-service';
import EnabledModel from './enabled-dataview-model';


/**
 * Enabled 部件服务对象
 *
 * @export
 * @class EnabledService
 */
export default class EnabledService extends ControlService {

    /**
     * 业务流程版本服务对象
     *
     * @type {PSWFVersionService}
     * @memberof EnabledService
     */
    public appEntityService: PSWFVersionService = new PSWFVersionService({ $store: this.getStore() });

    /**
     * 设置从数据模式
     *
     * @type {boolean}
     * @memberof EnabledService
     */
    public setTempMode(){
        this.isTempMode = false;
    }

    /**
     * Creates an instance of EnabledService.
     * 
     * @param {*} [opts={}]
     * @memberof EnabledService
     */
    constructor(opts: any = {}) {
        super(opts);
        this.model = new EnabledModel();
    }




    /**
     * 查询数据
     *
     * @param {string} action
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EnabledService
     */
    @Errorlog
    public search(action: string,context: any = {}, data: any = {}, isloading?: boolean): Promise<any> {
        const {data:Data,context:Context} = this.handleRequestData(action,context,data,true);
        return new Promise((resolve: any, reject: any) => {
            const _appEntityService: any = this.appEntityService;
            let result: Promise<any>;
            if (_appEntityService[action] && _appEntityService[action] instanceof Function) {
                result = _appEntityService[action](Context,Data, isloading);
            }else{
                result =_appEntityService.FetchDefault(Context,Data, isloading);
            }
            result.then((response) => {
                this.handleResponse(action, response);
                resolve(response);
            }).catch(response => {
                reject(response);
            });      
        });
    }

    /**
     * 删除数据
     *
     * @param {string} action
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof EnabledService
     */
    @Errorlog
    public delete(action: string,context: any = {}, data: any = {}, isloading?: boolean): Promise<any> {
        const {data:Data,context:Context} = this.handleRequestData(action,context,data,true);
        return new Promise((resolve: any, reject: any) => {
            const _appEntityService: any = this.appEntityService;
            let result: Promise<any>;
            if (_appEntityService[action] && _appEntityService[action] instanceof Function) {
                result = _appEntityService[action](Context,Data, isloading);
            }else{
                result =_appEntityService.remove(Context,Data, isloading);
            }
            result.then((response) => {
                this.handleResponse(action, response);
                resolve(response);
            }).catch(response => {
                reject(response);
            });      
        });
    }



}