import Vue from 'vue';
import Router from 'vue-router';
import { AuthGuard } from '@/utils';
import qs from 'qs';

Vue.use(Router);

const router = new Router({
    routes: [
        {
            path: '/indexview/:indexview?',
            beforeEnter: (to: any, from: any, next: any) => {
                const routerParamsName = 'indexview';
                const params: any = {};
                if (to.params && to.params[routerParamsName]) {
                    Object.assign(params, qs.parse(to.params[routerParamsName], { delimiter: ';' }));
                }
                const url: string = '/appdata';
                const auth: Promise<any> = AuthGuard.getInstance().authGuard(url, params, router);
                auth.then(() => {
                    next();
                }).catch(() => {
                    next();
                });
            },
            meta: {  
                caption: '工作流平台首页',
                viewType: 'APPINDEX',
                parameters: [
                    { pathName: 'indexview', parameterName: 'indexview' },
                ],
                requireAuth: true,
            },
            component: () => import('@pages/ungroup/index-view/index-view.vue'),
            children: [
                {
                    path: 'orgusers/:orguser?/pickupview/:pickupview?',
                    meta: {
                        caption: 'orguser.views.pickupview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-user-pickup-view/org-user-pickup-view.vue'),
                },
                {
                    path: 'orgs/:org?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'org.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-pickup-grid-view/org-pickup-grid-view.vue'),
                },
                {
                    path: 'pswfroles/:pswfrole?/pswfroledetails/:pswfroledetail?/editview/:editview?',
                    meta: {
                        caption: 'pswfroledetail.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroles', parameterName: 'pswfrole' },
                            { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-detail-edit-view/pswfrole-detail-edit-view.vue'),
                },
                {
                    path: 'pswfroledetails/:pswfroledetail?/editview/:editview?',
                    meta: {
                        caption: 'pswfroledetail.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-detail-edit-view/pswfrole-detail-edit-view.vue'),
                },
                {
                    path: 'orgdeptusers/:orgdeptuser?/gridview/:gridview?',
                    meta: {
                        caption: 'orgdeptuser.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-user-grid-view/org-dept-user-grid-view.vue'),
                },
                {
                    path: 'pswfroles/:pswfrole?/curorggridview/:curorggridview?',
                    meta: {
                        caption: 'pswfrole.views.curorggridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroles', parameterName: 'pswfrole' },
                            { pathName: 'curorggridview', parameterName: 'curorggridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-cur-org-grid-view/pswfrole-cur-org-grid-view.vue'),
                },
                {
                    path: 'psworkflows/:psworkflow?/pswfversions/:pswfversion?/editview/:editview?',
                    meta: {
                        caption: 'pswfversion.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psworkflows', parameterName: 'psworkflow' },
                            { pathName: 'pswfversions', parameterName: 'pswfversion' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfversion-edit-view/pswfversion-edit-view.vue'),
                },
                {
                    path: 'pswfversions/:pswfversion?/editview/:editview?',
                    meta: {
                        caption: 'pswfversion.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfversions', parameterName: 'pswfversion' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfversion-edit-view/pswfversion-edit-view.vue'),
                },
                {
                    path: 'orgs/:org?/editview/:editview?',
                    meta: {
                        caption: 'org.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-edit-view/org-edit-view.vue'),
                },
                {
                    path: 'orgs/:org?/gridview/:gridview?',
                    meta: {
                        caption: 'org.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-grid-view/org-grid-view.vue'),
                },
                {
                    path: 'psworkflows/:psworkflow?/curorggridview/:curorggridview?',
                    meta: {
                        caption: 'psworkflow.views.curorggridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psworkflows', parameterName: 'psworkflow' },
                            { pathName: 'curorggridview', parameterName: 'curorggridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/psworkflow-cur-org-grid-view/psworkflow-cur-org-grid-view.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/pickupview/:pickupview?',
                    meta: {
                        caption: 'orgdept.views.pickupview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-pickup-view/org-dept-pickup-view.vue'),
                },
                {
                    path: 'pswfroles/:pswfrole?/pswfroledetails/:pswfroledetail?/gridview/:gridview?',
                    meta: {
                        caption: 'pswfroledetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroles', parameterName: 'pswfrole' },
                            { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-detail-grid-view/pswfrole-detail-grid-view.vue'),
                },
                {
                    path: 'pswfroledetails/:pswfroledetail?/gridview/:gridview?',
                    meta: {
                        caption: 'pswfroledetail.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-detail-grid-view/pswfrole-detail-grid-view.vue'),
                },
                {
                    path: 'psworkflows/:psworkflow?/editview/:editview?',
                    meta: {
                        caption: 'psworkflow.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psworkflows', parameterName: 'psworkflow' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/psworkflow-edit-view/psworkflow-edit-view.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/gridview/:gridview?',
                    meta: {
                        caption: 'orgdept.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-grid-view/org-dept-grid-view.vue'),
                },
                {
                    path: 'orgdeptusers/:orgdeptuser?/editview/:editview?',
                    meta: {
                        caption: 'orgdeptuser.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-user-edit-view/org-dept-user-edit-view.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'orgdept.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-pickup-grid-view/org-dept-pickup-grid-view.vue'),
                },
                {
                    path: 'orgusers/:orguser?/gridview/:gridview?',
                    meta: {
                        caption: 'orguser.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-user-grid-view/org-user-grid-view.vue'),
                },
                {
                    path: 'orgusers/:orguser?/editview3/:editview3?',
                    meta: {
                        caption: 'orguser.views.editview3.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'editview3', parameterName: 'editview3' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-user-edit-view3/org-user-edit-view3.vue'),
                },
                {
                    path: 'pswfroles/:pswfrole?/editview/:editview?',
                    meta: {
                        caption: 'pswfrole.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfroles', parameterName: 'pswfrole' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfrole-edit-view/pswfrole-edit-view.vue'),
                },
                {
                    path: 'psworkflows/:psworkflow?/pswfversions/:pswfversion?/gridview/:gridview?',
                    meta: {
                        caption: 'pswfversion.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'psworkflows', parameterName: 'psworkflow' },
                            { pathName: 'pswfversions', parameterName: 'pswfversion' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfversion-grid-view/pswfversion-grid-view.vue'),
                },
                {
                    path: 'pswfversions/:pswfversion?/gridview/:gridview?',
                    meta: {
                        caption: 'pswfversion.views.gridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'pswfversions', parameterName: 'pswfversion' },
                            { pathName: 'gridview', parameterName: 'gridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-wf/pswfversion-grid-view/pswfversion-grid-view.vue'),
                },
                {
                    path: 'orgs/:org?/pickupview/:pickupview?',
                    meta: {
                        caption: 'org.views.pickupview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgs', parameterName: 'org' },
                            { pathName: 'pickupview', parameterName: 'pickupview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-pickup-view/org-pickup-view.vue'),
                },
                {
                    path: 'orgusers/:orguser?/pickupgridview/:pickupgridview?',
                    meta: {
                        caption: 'orguser.views.pickupgridview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgusers', parameterName: 'orguser' },
                            { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-user-pickup-grid-view/org-user-pickup-grid-view.vue'),
                },
                {
                    path: 'orgdepts/:orgdept?/editview/:editview?',
                    meta: {
                        caption: 'orgdept.views.editview.caption',
                        parameters: [
                            { pathName: 'indexview', parameterName: 'indexview' },
                            { pathName: 'orgdepts', parameterName: 'orgdept' },
                            { pathName: 'editview', parameterName: 'editview' },
                        ],
                        requireAuth: true,
                    },
                    component: () => import('@pages/r7rt-org/org-dept-edit-view/org-dept-edit-view.vue'),
                },
            ],
        },
    {
        path: '/orgs/:org?/editview/:editview?',
        meta: {
            caption: 'org.views.editview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-edit-view/org-edit-view.vue'),
    },
    {
        path: '/psworkflows/:psworkflow?/curorggridview/:curorggridview?',
        meta: {
            caption: 'psworkflow.views.curorggridview.caption',
            parameters: [
                { pathName: 'psworkflows', parameterName: 'psworkflow' },
                { pathName: 'curorggridview', parameterName: 'curorggridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/psworkflow-cur-org-grid-view/psworkflow-cur-org-grid-view.vue'),
    },
    {
        path: '/orgs/:org?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'org.views.pickupgridview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-pickup-grid-view/org-pickup-grid-view.vue'),
    },
    {
        path: '/orgusers/:orguser?/editview3/:editview3?',
        meta: {
            caption: 'orguser.views.editview3.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'editview3', parameterName: 'editview3' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-user-edit-view3/org-user-edit-view3.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/pickupview/:pickupview?',
        meta: {
            caption: 'orgdept.views.pickupview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-pickup-view/org-dept-pickup-view.vue'),
    },
    {
        path: '/orgs/:org?/gridview/:gridview?',
        meta: {
            caption: 'org.views.gridview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-grid-view/org-grid-view.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'orgdept.views.pickupgridview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-pickup-grid-view/org-dept-pickup-grid-view.vue'),
    },
    {
        path: '/orgusers/:orguser?/gridview/:gridview?',
        meta: {
            caption: 'orguser.views.gridview.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-user-grid-view/org-user-grid-view.vue'),
    },
    {
        path: '/orgdeptusers/:orgdeptuser?/editview/:editview?',
        meta: {
            caption: 'orgdeptuser.views.editview.caption',
            parameters: [
                { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-user-edit-view/org-dept-user-edit-view.vue'),
    },
    {
        path: '/orgs/:org?/pickupview/:pickupview?',
        meta: {
            caption: 'org.views.pickupview.caption',
            parameters: [
                { pathName: 'orgs', parameterName: 'org' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-pickup-view/org-pickup-view.vue'),
    },
    {
        path: '/orgusers/:orguser?/pickupgridview/:pickupgridview?',
        meta: {
            caption: 'orguser.views.pickupgridview.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'pickupgridview', parameterName: 'pickupgridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-user-pickup-grid-view/org-user-pickup-grid-view.vue'),
    },
    {
        path: '/orgusers/:orguser?/pickupview/:pickupview?',
        meta: {
            caption: 'orguser.views.pickupview.caption',
            parameters: [
                { pathName: 'orgusers', parameterName: 'orguser' },
                { pathName: 'pickupview', parameterName: 'pickupview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-user-pickup-view/org-user-pickup-view.vue'),
    },
    {
        path: '/pswfroles/:pswfrole?/pswfroledetails/:pswfroledetail?/editview/:editview?',
        meta: {
            caption: 'pswfroledetail.views.editview.caption',
            parameters: [
                { pathName: 'pswfroles', parameterName: 'pswfrole' },
                { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-detail-edit-view/pswfrole-detail-edit-view.vue'),
    },
    {
        path: '/pswfroledetails/:pswfroledetail?/editview/:editview?',
        meta: {
            caption: 'pswfroledetail.views.editview.caption',
            parameters: [
                { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-detail-edit-view/pswfrole-detail-edit-view.vue'),
    },
    {
        path: '/pswfroles/:pswfrole?/pswfroledetails/:pswfroledetail?/gridview/:gridview?',
        meta: {
            caption: 'pswfroledetail.views.gridview.caption',
            parameters: [
                { pathName: 'pswfroles', parameterName: 'pswfrole' },
                { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-detail-grid-view/pswfrole-detail-grid-view.vue'),
    },
    {
        path: '/pswfroledetails/:pswfroledetail?/gridview/:gridview?',
        meta: {
            caption: 'pswfroledetail.views.gridview.caption',
            parameters: [
                { pathName: 'pswfroledetails', parameterName: 'pswfroledetail' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-detail-grid-view/pswfrole-detail-grid-view.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/gridview/:gridview?',
        meta: {
            caption: 'orgdept.views.gridview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-grid-view/org-dept-grid-view.vue'),
    },
    {
        path: '/pswfroles/:pswfrole?/editview/:editview?',
        meta: {
            caption: 'pswfrole.views.editview.caption',
            parameters: [
                { pathName: 'pswfroles', parameterName: 'pswfrole' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-edit-view/pswfrole-edit-view.vue'),
    },
    {
        path: '/pswfroles/:pswfrole?/curorggridview/:curorggridview?',
        meta: {
            caption: 'pswfrole.views.curorggridview.caption',
            parameters: [
                { pathName: 'pswfroles', parameterName: 'pswfrole' },
                { pathName: 'curorggridview', parameterName: 'curorggridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfrole-cur-org-grid-view/pswfrole-cur-org-grid-view.vue'),
    },
    {
        path: '/psworkflows/:psworkflow?/editview/:editview?',
        meta: {
            caption: 'psworkflow.views.editview.caption',
            parameters: [
                { pathName: 'psworkflows', parameterName: 'psworkflow' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/psworkflow-edit-view/psworkflow-edit-view.vue'),
    },
    {
        path: '/orgdepts/:orgdept?/editview/:editview?',
        meta: {
            caption: 'orgdept.views.editview.caption',
            parameters: [
                { pathName: 'orgdepts', parameterName: 'orgdept' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-edit-view/org-dept-edit-view.vue'),
    },
    {
        path: '/orgdeptusers/:orgdeptuser?/gridview/:gridview?',
        meta: {
            caption: 'orgdeptuser.views.gridview.caption',
            parameters: [
                { pathName: 'orgdeptusers', parameterName: 'orgdeptuser' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-org/org-dept-user-grid-view/org-dept-user-grid-view.vue'),
    },
    {
        path: '/psworkflows/:psworkflow?/pswfversions/:pswfversion?/editview/:editview?',
        meta: {
            caption: 'pswfversion.views.editview.caption',
            parameters: [
                { pathName: 'psworkflows', parameterName: 'psworkflow' },
                { pathName: 'pswfversions', parameterName: 'pswfversion' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfversion-edit-view/pswfversion-edit-view.vue'),
    },
    {
        path: '/pswfversions/:pswfversion?/editview/:editview?',
        meta: {
            caption: 'pswfversion.views.editview.caption',
            parameters: [
                { pathName: 'pswfversions', parameterName: 'pswfversion' },
                { pathName: 'editview', parameterName: 'editview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfversion-edit-view/pswfversion-edit-view.vue'),
    },
    {
        path: '/psworkflows/:psworkflow?/pswfversions/:pswfversion?/gridview/:gridview?',
        meta: {
            caption: 'pswfversion.views.gridview.caption',
            parameters: [
                { pathName: 'psworkflows', parameterName: 'psworkflow' },
                { pathName: 'pswfversions', parameterName: 'pswfversion' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfversion-grid-view/pswfversion-grid-view.vue'),
    },
    {
        path: '/pswfversions/:pswfversion?/gridview/:gridview?',
        meta: {
            caption: 'pswfversion.views.gridview.caption',
            parameters: [
                { pathName: 'pswfversions', parameterName: 'pswfversion' },
                { pathName: 'gridview', parameterName: 'gridview' },
            ],
            requireAuth: true,
        },
        component: () => import('@pages/r7rt-wf/pswfversion-grid-view/pswfversion-grid-view.vue'),
    },
        {
            path: '/login/:login?',
            name: 'login',
            meta: {  
                caption: '登录',
                viewType: 'login',
                requireAuth: false,
                ignoreAddPage: true,
            },
            beforeEnter: (to: any, from: any, next: any) => {
                router.app.$store.commit('resetRootStateData');
                next();
            },
            component: () => import('@components/login/login.vue'),
        },
        {
            path: '/404',
            component: () => import('@components/404/404.vue')
        },
        {
            path: '/500',
            component: () => import('@components/500/500.vue')
        },
        {
            path: '*',
            redirect: 'indexview'
        },
    ],
});

export default router;
