import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 平台流程角色服务对象基类
 *
 * @export
 * @class PSWFRoleServiceBase
 * @extends {EntityServie}
 */
export default class PSWFRoleServiceBase extends EntityService {

    /**
     * Creates an instance of  PSWFRoleServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  PSWFRoleServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof PSWFRoleServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='pswfrole';
        this.APPDEKEY = 'pswfroleid';
        this.APPDENAME = 'pswfroles';
        this.APPDETEXT = 'pswfrolename';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().get(`/pswfroles/${context.pswfrole}/select`,isloading);
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/pswfroles/${context.pswfrole}/checkkey`,data,isloading);
    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let pswfroledetailsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pswfroledetails'),'undefined')){
            pswfroledetailsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pswfroledetails') as any);
        }
        masterData.pswfroledetails = pswfroledetailsData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/pswfroles/${context.pswfrole}`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_pswfroledetails',JSON.stringify(res.data.pswfroledetails));
            return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/pswfroles/${context.pswfrole}`,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_pswfroledetails',JSON.stringify(res.data.pswfroledetails));
            return res;

    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any = await  Http.getInstance().get(`/pswfroles/getdraft`,isloading);
        res.data.pswfrole = data.pswfrole;
            this.tempStorage.setItem(context.srfsessionkey+'_pswfroledetails',JSON.stringify(res.data.pswfroledetails));
        return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().delete(`/pswfroles/${context.pswfrole}`,isloading);

    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let pswfroledetailsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pswfroledetails'),'undefined')){
            pswfroledetailsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pswfroledetails') as any);
        }
        masterData.pswfroledetails = pswfroledetailsData;
        Object.assign(data,masterData);
        data[this.APPDEKEY] = null;
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/pswfroles`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_pswfroledetails',JSON.stringify(res.data.pswfroledetails));
        return res;
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let pswfroledetailsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pswfroledetails'),'undefined')){
            pswfroledetailsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pswfroledetails') as any);
        }
        masterData.pswfroledetails = pswfroledetailsData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/pswfroles/${context.pswfrole}/save`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_pswfroledetails',JSON.stringify(res.data.pswfroledetails));
            return res;
    }

    /**
     * FetchCurOrg接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async FetchCurOrg(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pswfroles/fetchcurorg`,tempData,isloading);
    }

    /**
     * FetchCurOrgDept接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async FetchCurOrgDept(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pswfroles/fetchcurorgdept`,tempData,isloading);
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/pswfroles/fetchdefault`,tempData,isloading);
    }

    /**
     * Regist接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWFRoleServiceBase
     */
    public async Regist(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        // URI参数传递情况未实现
    }
}