import { Http,Util } from '@/utils';
import EntityService from '../entity-service';



/**
 * 业务工作流服务对象基类
 *
 * @export
 * @class PSWorkflowServiceBase
 * @extends {EntityServie}
 */
export default class PSWorkflowServiceBase extends EntityService {

    /**
     * Creates an instance of  PSWorkflowServiceBase.
     * 
     * @param {*} [opts={}]
     * @memberof  PSWorkflowServiceBase
     */
    constructor(opts: any = {}) {
        super(opts);
    }

    /**
     * 初始化基础数据
     *
     * @memberof PSWorkflowServiceBase
     */
    public initBasicData(){
        this.APPLYDEKEY ='psworkflow';
        this.APPDEKEY = 'psworkflowid';
        this.APPDENAME = 'psworkflows';
        this.APPDETEXT = 'pswfworkflowname';
    }

// 实体接口

    /**
     * Select接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWorkflowServiceBase
     */
    public async Select(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().get(`/psworkflows/${context.psworkflow}/select`,isloading);
    }

    /**
     * Save接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWorkflowServiceBase
     */
    public async Save(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let pswfversionsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pswfversions'),'undefined')){
            pswfversionsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pswfversions') as any);
        }
        masterData.pswfversions = pswfversionsData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().post(`/psworkflows/${context.psworkflow}/save`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_pswfversions',JSON.stringify(res.data.pswfversions));
            return res;
    }

    /**
     * Remove接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWorkflowServiceBase
     */
    public async Remove(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().delete(`/psworkflows/${context.psworkflow}`,isloading);

    }

    /**
     * Update接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWorkflowServiceBase
     */
    public async Update(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let pswfversionsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pswfversions'),'undefined')){
            pswfversionsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pswfversions') as any);
        }
        masterData.pswfversions = pswfversionsData;
        Object.assign(data,masterData);
            let res:any = await  Http.getInstance().put(`/psworkflows/${context.psworkflow}`,data,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_pswfversions',JSON.stringify(res.data.pswfversions));
            return res;
    }

    /**
     * CheckKey接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWorkflowServiceBase
     */
    public async CheckKey(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            return Http.getInstance().post(`/psworkflows/${context.psworkflow}/checkkey`,data,isloading);
    }

    /**
     * Create接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWorkflowServiceBase
     */
    public async Create(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let masterData:any = {};
        let pswfversionsData:any = [];
        if(!Object.is(this.tempStorage.getItem(context.srfsessionkey+'_pswfversions'),'undefined')){
            pswfversionsData = JSON.parse(this.tempStorage.getItem(context.srfsessionkey+'_pswfversions') as any);
        }
        masterData.pswfversions = pswfversionsData;
        Object.assign(data,masterData);
        data[this.APPDEKEY] = null;
        let tempContext:any = JSON.parse(JSON.stringify(context));
        let res:any = await Http.getInstance().post(`/psworkflows`,data,isloading);
        this.tempStorage.setItem(tempContext.srfsessionkey+'_pswfversions',JSON.stringify(res.data.pswfversions));
        return res;
    }

    /**
     * GetDraft接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWorkflowServiceBase
     */
    public async GetDraft(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let res:any = await  Http.getInstance().get(`/psworkflows/getdraft`,isloading);
        res.data.psworkflow = data.psworkflow;
            this.tempStorage.setItem(context.srfsessionkey+'_pswfversions',JSON.stringify(res.data.pswfversions));
        return res;
    }

    /**
     * Get接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWorkflowServiceBase
     */
    public async Get(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
            let res:any = await Http.getInstance().get(`/psworkflows/${context.psworkflow}`,isloading);
            this.tempStorage.setItem(context.srfsessionkey+'_pswfversions',JSON.stringify(res.data.pswfversions));
            return res;

    }

    /**
     * FetchCurOrg接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWorkflowServiceBase
     */
    public async FetchCurOrg(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/psworkflows/fetchcurorg`,tempData,isloading);
    }

    /**
     * FetchCurOrgDept接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWorkflowServiceBase
     */
    public async FetchCurOrgDept(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/psworkflows/fetchcurorgdept`,tempData,isloading);
    }

    /**
     * FetchDefault接口方法
     *
     * @param {*} [context={}]
     * @param {*} [data={}]
     * @param {boolean} [isloading]
     * @returns {Promise<any>}
     * @memberof PSWorkflowServiceBase
     */
    public async FetchDefault(context: any = {},data: any = {}, isloading?: boolean): Promise<any> {
        let tempData:any = JSON.parse(JSON.stringify(data));
        return Http.getInstance().get(`/psworkflows/fetchdefault`,tempData,isloading);
    }
}