package cn.ibizlab.r7.runtime.wf.service.uniwfinternalservice.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.uniwfinternalservice.dto.PSWFVersionDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSWFVersion;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSWFVersionService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSWFVersionSearchContext;

@Api(tags = {"PSWFVersion" })
@RestController
@RequestMapping("")
public class PSWFVersionResource {

    @Autowired
    private IPSWFVersionService pswfversionService;

    public IPSWFVersionService getPswfversionService() {
        return this.pswfversionService;
    }

    @ApiOperation(value = "注册", tags = {"PSWFVersion" },  notes = "注册")
	@RequestMapping(method = RequestMethod.POST, value = "/uniwfinternalservice/pswfversions/regist")
    @Transactional
    public ResponseEntity<List<PSWFVersionDTO>> regist(@RequestBody List<PSWFVersionDTO> pswfversiondtos) {
        if (pswfversiondtos == null) {
            return ResponseEntity.status(HttpStatus.OK).body(null);
        }
        List<PSWFVersionDTO> pswfversiondtos2 = new ArrayList<PSWFVersionDTO>();
        for (PSWFVersionDTO pswfversiondto : pswfversiondtos) {
            PSWFVersion domain = pswfversiondto.toDO();
            pswfversionService.save(domain);
            pswfversiondto.fromDO(domain);
            pswfversiondtos2.add(pswfversiondto);
        }

		return ResponseEntity.status(HttpStatus.OK).body(pswfversiondtos2);
    }

    @ApiOperation(value = "Get", tags = {"PSWFVersion" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/uniwfinternalservice/pswfversions/{pswfversion_id}")
    public ResponseEntity<PSWFVersionDTO> get(@PathVariable("pswfversion_id") String pswfversion_id) {
        PSWFVersionDTO dto = new PSWFVersionDTO();
        PSWFVersion domain = pswfversionService.get(pswfversion_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSWFVersion" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/uniwfinternalservice/pswfversions/fetchdefault")
	public ResponseEntity<Page<PSWFVersionDTO>> fetchDefault(PSWFVersionSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWFVersionDTO> list = new ArrayList<PSWFVersionDTO>();
        
        Page<PSWFVersion> domains = pswfversionService.searchDefault(context) ;
        for(PSWFVersion pswfversion : domains.getContent()){
            PSWFVersionDTO dto = new PSWFVersionDTO();
            dto.fromDO(pswfversion);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
