package cn.ibizlab.r7.runtime.wf.service.uniwfinternalservice.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.uniwfinternalservice.dto.WFWorklistDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.WFWorklist;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWFWorklistService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WFWorklistSearchContext;

@Api(tags = {"WFWorklist" })
@RestController
@RequestMapping("")
public class WFWorklistResource {

    @Autowired
    private IWFWorklistService wfworklistService;

    public IWFWorklistService getWfworklistService() {
        return this.wfworklistService;
    }

    @ApiOperation(value = "Get", tags = {"WFWorklist" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/uniwfinternalservice/wfworklists/{wfworklist_id}")
    public ResponseEntity<WFWorklistDTO> get(@PathVariable("wfworklist_id") String wfworklist_id) {
        WFWorklistDTO dto = new WFWorklistDTO();
        WFWorklist domain = wfworklistService.get(wfworklist_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"WFWorklist" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/uniwfinternalservice/wfworklists/fetchdefault")
	public ResponseEntity<Page<WFWorklistDTO>> fetchDefault(WFWorklistSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFWorklistDTO> list = new ArrayList<WFWorklistDTO>();
        
        Page<WFWorklist> domains = wfworklistService.searchDefault(context) ;
        for(WFWorklist wfworklist : domains.getContent()){
            WFWorklistDTO dto = new WFWorklistDTO();
            dto.fromDO(wfworklist);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}

	@ApiOperation(value = "获取我的已办查询", tags = {"WFWorklist" } ,notes = "获取我的已办查询")
    @RequestMapping(method= RequestMethod.GET , value="/uniwfinternalservice/wfworklists/fetchdonetask")
	public ResponseEntity<Page<WFWorklistDTO>> fetchDoneTask(WFWorklistSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFWorklistDTO> list = new ArrayList<WFWorklistDTO>();
        
        Page<WFWorklist> domains = wfworklistService.searchDoneTask(context) ;
        for(WFWorklist wfworklist : domains.getContent()){
            WFWorklistDTO dto = new WFWorklistDTO();
            dto.fromDO(wfworklist);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}

	@ApiOperation(value = "获取我的待办查询", tags = {"WFWorklist" } ,notes = "获取我的待办查询")
    @RequestMapping(method= RequestMethod.GET , value="/uniwfinternalservice/wfworklists/fetchtodotask")
	public ResponseEntity<Page<WFWorklistDTO>> fetchTodoTask(WFWorklistSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFWorklistDTO> list = new ArrayList<WFWorklistDTO>();
        
        Page<WFWorklist> domains = wfworklistService.searchTodoTask(context) ;
        for(WFWorklist wfworklist : domains.getContent()){
            WFWorklistDTO dto = new WFWorklistDTO();
            dto.fromDO(wfworklist);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
