package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.EntityDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.Entity;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IEntityService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.EntitySearchContext;

@Api(tags = {"Entity" })
@RestController
@RequestMapping("")
public class EntityResource {

    @Autowired
    private IEntityService entityService;

    public IEntityService getEntityService() {
        return this.entityService;
    }

    @ApiOperation(value = "Get", tags = {"Entity" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/entities/{entity_id}")
    public ResponseEntity<EntityDTO> get(@PathVariable("entity_id") String entity_id) {
        EntityDTO dto = new EntityDTO();
        Entity domain = entityService.get(entity_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"Entity" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/entities/{entity_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody EntityDTO entitydto) {
        Entity entity = entitydto.toDO();
    	Boolean b = entityService.save(entity) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Create", tags = {"Entity" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/entities")
    @Transactional
    public ResponseEntity<EntityDTO> create(@RequestBody EntityDTO entitydto) {
        EntityDTO dto = new EntityDTO();
        Entity domain = entitydto.toDO();
		entityService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"Entity" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/entities/{entity_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("entity_id") String entity_id) {
        EntityDTO entitydto = new EntityDTO();
		Entity domain = new Entity();
		entitydto.setEntityId(entity_id);
		domain.setEntityId(entity_id);
        Boolean rst = entityService.remove(domain.getEntityId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "CheckKey", tags = {"Entity" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/entities/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody EntityDTO entitydto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Update", tags = {"Entity" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/entities/{entity_id}")
    @Transactional
    public ResponseEntity<EntityDTO> update(@PathVariable("entity_id") String entity_id, @RequestBody EntityDTO entitydto) {
		Entity domain = entitydto.toDO();
        domain.setEntityId(entity_id);
		entityService.update(domain);
		EntityDTO dto = new EntityDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"Entity" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/entities/{entity_id}/getdraft")
    @Transactional
    public ResponseEntity<EntityDTO> getDraft(@PathVariable("entity_id") String entity_id, @RequestBody EntityDTO entitydto) {
        Entity entity = entitydto.toDO();
    	entity = entityService.getDraft(entity) ;
    	entitydto.fromDO(entity);
        return ResponseEntity.status(HttpStatus.OK).body(entitydto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"Entity" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/entities/fetchdefault")
	public ResponseEntity<Page<EntityDTO>> fetchDefault(EntitySearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<EntityDTO> list = new ArrayList<EntityDTO>();
        
        Page<Entity> domains = entityService.searchDefault(context) ;
        for(Entity entity : domains.getContent()){
            EntityDTO dto = new EntityDTO();
            dto.fromDO(entity);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
