package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSDEWFDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSDEWF;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSDEWFService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSDEWFSearchContext;

@Api(tags = {"PSDEWF" })
@RestController
@RequestMapping("")
public class PSDEWFResource {

    @Autowired
    private IPSDEWFService psdewfService;

    public IPSDEWFService getPsdewfService() {
        return this.psdewfService;
    }

    @ApiOperation(value = "GetDraft", tags = {"PSDEWF" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/psdewfs/{psdewf_id}/getdraft")
    @Transactional
    public ResponseEntity<PSDEWFDTO> getDraft(@PathVariable("psdewf_id") String psdewf_id, @RequestBody PSDEWFDTO psdewfdto) {
        PSDEWF psdewf = psdewfdto.toDO();
    	psdewf = psdewfService.getDraft(psdewf) ;
    	psdewfdto.fromDO(psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(psdewfdto);
    }

    @ApiOperation(value = "Update", tags = {"PSDEWF" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/psdewfs/{psdewf_id}")
    @Transactional
    public ResponseEntity<PSDEWFDTO> update(@PathVariable("psdewf_id") String psdewf_id, @RequestBody PSDEWFDTO psdewfdto) {
		PSDEWF domain = psdewfdto.toDO();
        domain.setPSDEWFId(psdewf_id);
		psdewfService.update(domain);
		PSDEWFDTO dto = new PSDEWFDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"PSDEWF" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psdewfs/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSDEWFDTO psdewfdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Get", tags = {"PSDEWF" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/psdewfs/{psdewf_id}")
    public ResponseEntity<PSDEWFDTO> get(@PathVariable("psdewf_id") String psdewf_id) {
        PSDEWFDTO dto = new PSDEWFDTO();
        PSDEWF domain = psdewfService.get(psdewf_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Create", tags = {"PSDEWF" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psdewfs")
    @Transactional
    public ResponseEntity<PSDEWFDTO> create(@RequestBody PSDEWFDTO psdewfdto) {
        PSDEWFDTO dto = new PSDEWFDTO();
        PSDEWF domain = psdewfdto.toDO();
		psdewfService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"PSDEWF" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/psdewfs/{psdewf_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("psdewf_id") String psdewf_id) {
        PSDEWFDTO psdewfdto = new PSDEWFDTO();
		PSDEWF domain = new PSDEWF();
		psdewfdto.setPSDEWFId(psdewf_id);
		domain.setPSDEWFId(psdewf_id);
        Boolean rst = psdewfService.remove(domain.getPSDEWFId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Save", tags = {"PSDEWF" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psdewfs/{psdewf_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSDEWFDTO psdewfdto) {
        PSDEWF psdewf = psdewfdto.toDO();
    	Boolean b = psdewfService.save(psdewf) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSDEWF" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/psdewfs/fetchdefault")
	public ResponseEntity<Page<PSDEWFDTO>> fetchDefault(PSDEWFSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSDEWFDTO> list = new ArrayList<PSDEWFDTO>();
        
        Page<PSDEWF> domains = psdewfService.searchDefault(context) ;
        for(PSDEWF psdewf : domains.getContent()){
            PSDEWFDTO dto = new PSDEWFDTO();
            dto.fromDO(psdewf);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}



    @ApiOperation(value = "GetDraft", tags = {"PSDEWF" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/psworkflows/{psworkflow_id}/psdewfs/{psdewfpsdewfid}/getdraft")
    @Transactional
    public ResponseEntity<PSDEWFDTO> getDraftByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("psdewf_id") String psdewf_id, @RequestBody PSDEWFDTO psdewfdto) {
        PSDEWF psdewf = psdewfdto.toDO();
    	psdewf = psdewfService.getDraft(psdewf) ;
    	psdewfdto.fromDO(psdewf);
        return ResponseEntity.status(HttpStatus.OK).body(psdewfdto);
    }

    @ApiOperation(value = "Update", tags = {"PSDEWF" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/psworkflows/{psworkflow_id}/psdewfs/{psdewf_id}")
    @Transactional
    public ResponseEntity<PSDEWFDTO> updateByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("psdewf_id") String psdewf_id, @RequestBody PSDEWFDTO psdewfdto) {
		PSDEWF domain = psdewfdto.toDO();
        domain.setPSWorkflowId(psworkflow_id);
        domain.setPSDEWFId(psdewf_id);
		psdewfService.update(domain);
		PSDEWFDTO dto = new PSDEWFDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"PSDEWF" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psworkflows/{psworkflow_id}/psdewfs/checkkey")
    public ResponseEntity<Boolean> checkKeyByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSDEWFDTO psdewfdto) {

        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Get", tags = {"PSDEWF" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/psworkflows/{psworkflow_id}/psdewfs/{psdewf_id}")
    public ResponseEntity<PSDEWFDTO> getByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("psdewf_id") String psdewf_id) {
        PSDEWFDTO dto = new PSDEWFDTO();
        PSDEWF domain = psdewfService.get(psdewf_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Create", tags = {"PSDEWF" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psworkflows/{psworkflow_id}/psdewfs")
    @Transactional
    public ResponseEntity<PSDEWFDTO> createByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSDEWFDTO psdewfdto) {
        PSDEWFDTO dto = new PSDEWFDTO();
        PSDEWF domain = psdewfdto.toDO();
        domain.setPSWorkflowId(psworkflow_id);
		psdewfService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"PSDEWF" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/psworkflows/{psworkflow_id}/psdewfs/{psdewf_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("psdewf_id") String psdewf_id) {
        PSDEWFDTO psdewfdto = new PSDEWFDTO();
		PSDEWF domain = new PSDEWF();
		psdewfdto.setPSDEWFId(psdewf_id);
		domain.setPSDEWFId(psdewf_id);
        Boolean rst = psdewfService.remove(domain.getPSDEWFId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Save", tags = {"PSDEWF" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psworkflows/{psworkflow_id}/psdewfs/save")
    public ResponseEntity<Boolean> saveByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSDEWFDTO psdewfdto) {
        PSDEWF domain = psdewfdto.toDO();
        domain.setPSWorkflowId(psworkflow_id);
    	Boolean b = psdewfService.save(domain) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSDEWF" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/psworkflows/{psworkflow_id}/psdewfs/fetchdefault")
	public ResponseEntity<Page<PSDEWFDTO>> fetchPSDEWFDefault(@PathVariable("psworkflow_id") String psworkflow_id,PSDEWFSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSDEWFDTO> list = new ArrayList<PSDEWFDTO>();
        context.setN_psworkflowid_eq(psworkflow_id);
        Page<PSDEWF> domains = psdewfService.searchDefault(context) ;
        for(PSDEWF psdewf : domains.getContent()){
            PSDEWFDTO dto = new PSDEWFDTO();
            dto.fromDO(psdewf);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
