package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSDataEntityDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSDataEntity;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSDataEntityService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSDataEntitySearchContext;

@Api(tags = {"PSDataEntity" })
@RestController
@RequestMapping("")
public class PSDataEntityResource {

    @Autowired
    private IPSDataEntityService psdataentityService;

    public IPSDataEntityService getPsdataentityService() {
        return this.psdataentityService;
    }

    @ApiOperation(value = "GetDraft", tags = {"PSDataEntity" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/psdataentities/{psdataentity_id}/getdraft")
    @Transactional
    public ResponseEntity<PSDataEntityDTO> getDraft(@PathVariable("psdataentity_id") String psdataentity_id, @RequestBody PSDataEntityDTO psdataentitydto) {
        PSDataEntity psdataentity = psdataentitydto.toDO();
    	psdataentity = psdataentityService.getDraft(psdataentity) ;
    	psdataentitydto.fromDO(psdataentity);
        return ResponseEntity.status(HttpStatus.OK).body(psdataentitydto);
    }

    @ApiOperation(value = "Update", tags = {"PSDataEntity" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/psdataentities/{psdataentity_id}")
    @Transactional
    public ResponseEntity<PSDataEntityDTO> update(@PathVariable("psdataentity_id") String psdataentity_id, @RequestBody PSDataEntityDTO psdataentitydto) {
		PSDataEntity domain = psdataentitydto.toDO();
        domain.setPSDataEntityId(psdataentity_id);
		psdataentityService.update(domain);
		PSDataEntityDTO dto = new PSDataEntityDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"PSDataEntity" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/psdataentities/{psdataentity_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("psdataentity_id") String psdataentity_id) {
        PSDataEntityDTO psdataentitydto = new PSDataEntityDTO();
		PSDataEntity domain = new PSDataEntity();
		psdataentitydto.setPSDataEntityId(psdataentity_id);
		domain.setPSDataEntityId(psdataentity_id);
        Boolean rst = psdataentityService.remove(domain.getPSDataEntityId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Create", tags = {"PSDataEntity" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psdataentities")
    @Transactional
    public ResponseEntity<PSDataEntityDTO> create(@RequestBody PSDataEntityDTO psdataentitydto) {
        PSDataEntityDTO dto = new PSDataEntityDTO();
        PSDataEntity domain = psdataentitydto.toDO();
		psdataentityService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"PSDataEntity" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psdataentities/{psdataentity_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSDataEntityDTO psdataentitydto) {
        PSDataEntity psdataentity = psdataentitydto.toDO();
    	Boolean b = psdataentityService.save(psdataentity) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Get", tags = {"PSDataEntity" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/psdataentities/{psdataentity_id}")
    public ResponseEntity<PSDataEntityDTO> get(@PathVariable("psdataentity_id") String psdataentity_id) {
        PSDataEntityDTO dto = new PSDataEntityDTO();
        PSDataEntity domain = psdataentityService.get(psdataentity_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"PSDataEntity" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psdataentities/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSDataEntityDTO psdataentitydto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSDataEntity" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/psdataentities/fetchdefault")
	public ResponseEntity<Page<PSDataEntityDTO>> fetchDefault(PSDataEntitySearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSDataEntityDTO> list = new ArrayList<PSDataEntityDTO>();
        
        Page<PSDataEntity> domains = psdataentityService.searchDefault(context) ;
        for(PSDataEntity psdataentity : domains.getContent()){
            PSDataEntityDTO dto = new PSDataEntityDTO();
            dto.fromDO(psdataentity);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
