package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSSysAppDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSSysApp;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSSysAppService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSSysAppSearchContext;

@Api(tags = {"PSSysApp" })
@RestController
@RequestMapping("")
public class PSSysAppResource {

    @Autowired
    private IPSSysAppService pssysappService;

    public IPSSysAppService getPssysappService() {
        return this.pssysappService;
    }

    @ApiOperation(value = "Get", tags = {"PSSysApp" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pssysapps/{pssysapp_id}")
    public ResponseEntity<PSSysAppDTO> get(@PathVariable("pssysapp_id") String pssysapp_id) {
        PSSysAppDTO dto = new PSSysAppDTO();
        PSSysApp domain = pssysappService.get(pssysapp_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"PSSysApp" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pssysapps/{pssysapp_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSSysAppDTO pssysappdto) {
        PSSysApp pssysapp = pssysappdto.toDO();
    	Boolean b = pssysappService.save(pssysapp) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Create", tags = {"PSSysApp" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pssysapps")
    @Transactional
    public ResponseEntity<PSSysAppDTO> create(@RequestBody PSSysAppDTO pssysappdto) {
        PSSysAppDTO dto = new PSSysAppDTO();
        PSSysApp domain = pssysappdto.toDO();
		pssysappService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"PSSysApp" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pssysapps/{pssysapp_id}/getdraft")
    @Transactional
    public ResponseEntity<PSSysAppDTO> getDraft(@PathVariable("pssysapp_id") String pssysapp_id, @RequestBody PSSysAppDTO pssysappdto) {
        PSSysApp pssysapp = pssysappdto.toDO();
    	pssysapp = pssysappService.getDraft(pssysapp) ;
    	pssysappdto.fromDO(pssysapp);
        return ResponseEntity.status(HttpStatus.OK).body(pssysappdto);
    }

    @ApiOperation(value = "Remove", tags = {"PSSysApp" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/pssysapps/{pssysapp_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pssysapp_id") String pssysapp_id) {
        PSSysAppDTO pssysappdto = new PSSysAppDTO();
		PSSysApp domain = new PSSysApp();
		pssysappdto.setPSSysAppId(pssysapp_id);
		domain.setPSSysAppId(pssysapp_id);
        Boolean rst = pssysappService.remove(domain.getPSSysAppId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "CheckKey", tags = {"PSSysApp" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pssysapps/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSSysAppDTO pssysappdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Update", tags = {"PSSysApp" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/pssysapps/{pssysapp_id}")
    @Transactional
    public ResponseEntity<PSSysAppDTO> update(@PathVariable("pssysapp_id") String pssysapp_id, @RequestBody PSSysAppDTO pssysappdto) {
		PSSysApp domain = pssysappdto.toDO();
        domain.setPSSysAppId(pssysapp_id);
		pssysappService.update(domain);
		PSSysAppDTO dto = new PSSysAppDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSSysApp" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pssysapps/fetchdefault")
	public ResponseEntity<Page<PSSysAppDTO>> fetchDefault(PSSysAppSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSSysAppDTO> list = new ArrayList<PSSysAppDTO>();
        
        Page<PSSysApp> domains = pssysappService.searchDefault(context) ;
        for(PSSysApp pssysapp : domains.getContent()){
            PSSysAppDTO dto = new PSSysAppDTO();
            dto.fromDO(pssysapp);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
