package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSSysWFCatDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSSysWFCat;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSSysWFCatService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSSysWFCatSearchContext;

@Api(tags = {"PSSysWFCat" })
@RestController
@RequestMapping("")
public class PSSysWFCatResource {

    @Autowired
    private IPSSysWFCatService pssyswfcatService;

    public IPSSysWFCatService getPssyswfcatService() {
        return this.pssyswfcatService;
    }

    @ApiOperation(value = "Get", tags = {"PSSysWFCat" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pssyswfcats/{pssyswfcat_id}")
    public ResponseEntity<PSSysWFCatDTO> get(@PathVariable("pssyswfcat_id") String pssyswfcat_id) {
        PSSysWFCatDTO dto = new PSSysWFCatDTO();
        PSSysWFCat domain = pssyswfcatService.get(pssyswfcat_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"PSSysWFCat" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pssyswfcats/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSSysWFCatDTO pssyswfcatdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Update", tags = {"PSSysWFCat" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/pssyswfcats/{pssyswfcat_id}")
    @Transactional
    public ResponseEntity<PSSysWFCatDTO> update(@PathVariable("pssyswfcat_id") String pssyswfcat_id, @RequestBody PSSysWFCatDTO pssyswfcatdto) {
		PSSysWFCat domain = pssyswfcatdto.toDO();
        domain.setPSSysWFCatId(pssyswfcat_id);
		pssyswfcatService.update(domain);
		PSSysWFCatDTO dto = new PSSysWFCatDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"PSSysWFCat" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pssyswfcats/{pssyswfcat_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSSysWFCatDTO pssyswfcatdto) {
        PSSysWFCat pssyswfcat = pssyswfcatdto.toDO();
    	Boolean b = pssyswfcatService.save(pssyswfcat) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Create", tags = {"PSSysWFCat" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pssyswfcats")
    @Transactional
    public ResponseEntity<PSSysWFCatDTO> create(@RequestBody PSSysWFCatDTO pssyswfcatdto) {
        PSSysWFCatDTO dto = new PSSysWFCatDTO();
        PSSysWFCat domain = pssyswfcatdto.toDO();
		pssyswfcatService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"PSSysWFCat" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pssyswfcats/{pssyswfcat_id}/getdraft")
    @Transactional
    public ResponseEntity<PSSysWFCatDTO> getDraft(@PathVariable("pssyswfcat_id") String pssyswfcat_id, @RequestBody PSSysWFCatDTO pssyswfcatdto) {
        PSSysWFCat pssyswfcat = pssyswfcatdto.toDO();
    	pssyswfcat = pssyswfcatService.getDraft(pssyswfcat) ;
    	pssyswfcatdto.fromDO(pssyswfcat);
        return ResponseEntity.status(HttpStatus.OK).body(pssyswfcatdto);
    }

    @ApiOperation(value = "Remove", tags = {"PSSysWFCat" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/pssyswfcats/{pssyswfcat_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pssyswfcat_id") String pssyswfcat_id) {
        PSSysWFCatDTO pssyswfcatdto = new PSSysWFCatDTO();
		PSSysWFCat domain = new PSSysWFCat();
		pssyswfcatdto.setPSSysWFCatId(pssyswfcat_id);
		domain.setPSSysWFCatId(pssyswfcat_id);
        Boolean rst = pssyswfcatService.remove(domain.getPSSysWFCatId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSSysWFCat" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pssyswfcats/fetchdefault")
	public ResponseEntity<Page<PSSysWFCatDTO>> fetchDefault(PSSysWFCatSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSSysWFCatDTO> list = new ArrayList<PSSysWFCatDTO>();
        
        Page<PSSysWFCat> domains = pssyswfcatService.searchDefault(context) ;
        for(PSSysWFCat pssyswfcat : domains.getContent()){
            PSSysWFCatDTO dto = new PSSysWFCatDTO();
            dto.fromDO(pssyswfcat);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
