package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSSystemDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSSystem;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSSystemService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSSystemSearchContext;

@Api(tags = {"PSSystem" })
@RestController
@RequestMapping("")
public class PSSystemResource {

    @Autowired
    private IPSSystemService pssystemService;

    public IPSSystemService getPssystemService() {
        return this.pssystemService;
    }

    @ApiOperation(value = "Remove", tags = {"PSSystem" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/pssystems/{pssystem_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pssystem_id") String pssystem_id) {
        PSSystemDTO pssystemdto = new PSSystemDTO();
		PSSystem domain = new PSSystem();
		pssystemdto.setPSSystemId(pssystem_id);
		domain.setPSSystemId(pssystem_id);
        Boolean rst = pssystemService.remove(domain.getPSSystemId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Save", tags = {"PSSystem" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pssystems/{pssystem_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSSystemDTO pssystemdto) {
        PSSystem pssystem = pssystemdto.toDO();
    	Boolean b = pssystemService.save(pssystem) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Get", tags = {"PSSystem" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pssystems/{pssystem_id}")
    public ResponseEntity<PSSystemDTO> get(@PathVariable("pssystem_id") String pssystem_id) {
        PSSystemDTO dto = new PSSystemDTO();
        PSSystem domain = pssystemService.get(pssystem_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Create", tags = {"PSSystem" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pssystems")
    @Transactional
    public ResponseEntity<PSSystemDTO> create(@RequestBody PSSystemDTO pssystemdto) {
        PSSystemDTO dto = new PSSystemDTO();
        PSSystem domain = pssystemdto.toDO();
		pssystemService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Update", tags = {"PSSystem" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/pssystems/{pssystem_id}")
    @Transactional
    public ResponseEntity<PSSystemDTO> update(@PathVariable("pssystem_id") String pssystem_id, @RequestBody PSSystemDTO pssystemdto) {
		PSSystem domain = pssystemdto.toDO();
        domain.setPSSystemId(pssystem_id);
		pssystemService.update(domain);
		PSSystemDTO dto = new PSSystemDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"PSSystem" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pssystems/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSSystemDTO pssystemdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraft", tags = {"PSSystem" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pssystems/{pssystem_id}/getdraft")
    @Transactional
    public ResponseEntity<PSSystemDTO> getDraft(@PathVariable("pssystem_id") String pssystem_id, @RequestBody PSSystemDTO pssystemdto) {
        PSSystem pssystem = pssystemdto.toDO();
    	pssystem = pssystemService.getDraft(pssystem) ;
    	pssystemdto.fromDO(pssystem);
        return ResponseEntity.status(HttpStatus.OK).body(pssystemdto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSSystem" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pssystems/fetchdefault")
	public ResponseEntity<Page<PSSystemDTO>> fetchDefault(PSSystemSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSSystemDTO> list = new ArrayList<PSSystemDTO>();
        
        Page<PSSystem> domains = pssystemService.searchDefault(context) ;
        for(PSSystem pssystem : domains.getContent()){
            PSSystemDTO dto = new PSSystemDTO();
            dto.fromDO(pssystem);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
