package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSWFLinkDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSWFLink;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSWFLinkService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSWFLinkSearchContext;

@Api(tags = {"PSWFLink" })
@RestController
@RequestMapping("")
public class PSWFLinkResource {

    @Autowired
    private IPSWFLinkService pswflinkService;

    public IPSWFLinkService getPswflinkService() {
        return this.pswflinkService;
    }

    @ApiOperation(value = "CheckKey", tags = {"PSWFLink" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswflinks/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSWFLinkDTO pswflinkdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Remove", tags = {"PSWFLink" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/pswflinks/{pswflink_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pswflink_id") String pswflink_id) {
        PSWFLinkDTO pswflinkdto = new PSWFLinkDTO();
		PSWFLink domain = new PSWFLink();
		pswflinkdto.setPSWFLinkId(pswflink_id);
		domain.setPSWFLinkId(pswflink_id);
        Boolean rst = pswflinkService.remove(domain.getPSWFLinkId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Get", tags = {"PSWFLink" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswflinks/{pswflink_id}")
    public ResponseEntity<PSWFLinkDTO> get(@PathVariable("pswflink_id") String pswflink_id) {
        PSWFLinkDTO dto = new PSWFLinkDTO();
        PSWFLink domain = pswflinkService.get(pswflink_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"PSWFLink" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswflinks/{pswflink_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSWFLinkDTO pswflinkdto) {
        PSWFLink pswflink = pswflinkdto.toDO();
    	Boolean b = pswflinkService.save(pswflink) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Create", tags = {"PSWFLink" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswflinks")
    @Transactional
    public ResponseEntity<PSWFLinkDTO> create(@RequestBody PSWFLinkDTO pswflinkdto) {
        PSWFLinkDTO dto = new PSWFLinkDTO();
        PSWFLink domain = pswflinkdto.toDO();
		pswflinkService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"PSWFLink" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswflinks/{pswflink_id}/getdraft")
    @Transactional
    public ResponseEntity<PSWFLinkDTO> getDraft(@PathVariable("pswflink_id") String pswflink_id, @RequestBody PSWFLinkDTO pswflinkdto) {
        PSWFLink pswflink = pswflinkdto.toDO();
    	pswflink = pswflinkService.getDraft(pswflink) ;
    	pswflinkdto.fromDO(pswflink);
        return ResponseEntity.status(HttpStatus.OK).body(pswflinkdto);
    }

    @ApiOperation(value = "Update", tags = {"PSWFLink" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/pswflinks/{pswflink_id}")
    @Transactional
    public ResponseEntity<PSWFLinkDTO> update(@PathVariable("pswflink_id") String pswflink_id, @RequestBody PSWFLinkDTO pswflinkdto) {
		PSWFLink domain = pswflinkdto.toDO();
        domain.setPSWFLinkId(pswflink_id);
		pswflinkService.update(domain);
		PSWFLinkDTO dto = new PSWFLinkDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSWFLink" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pswflinks/fetchdefault")
	public ResponseEntity<Page<PSWFLinkDTO>> fetchDefault(PSWFLinkSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWFLinkDTO> list = new ArrayList<PSWFLinkDTO>();
        
        Page<PSWFLink> domains = pswflinkService.searchDefault(context) ;
        for(PSWFLink pswflink : domains.getContent()){
            PSWFLinkDTO dto = new PSWFLinkDTO();
            dto.fromDO(pswflink);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
