package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSWFProcRoleDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSWFProcRole;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSWFProcRoleService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSWFProcRoleSearchContext;

@Api(tags = {"PSWFProcRole" })
@RestController
@RequestMapping("")
public class PSWFProcRoleResource {

    @Autowired
    private IPSWFProcRoleService pswfprocroleService;

    public IPSWFProcRoleService getPswfprocroleService() {
        return this.pswfprocroleService;
    }

    @ApiOperation(value = "Create", tags = {"PSWFProcRole" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfprocroles")
    @Transactional
    public ResponseEntity<PSWFProcRoleDTO> create(@RequestBody PSWFProcRoleDTO pswfprocroledto) {
        PSWFProcRoleDTO dto = new PSWFProcRoleDTO();
        PSWFProcRole domain = pswfprocroledto.toDO();
		pswfprocroleService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"PSWFProcRole" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfprocroles/{pswfprocrole_id}/getdraft")
    @Transactional
    public ResponseEntity<PSWFProcRoleDTO> getDraft(@PathVariable("pswfprocrole_id") String pswfprocrole_id, @RequestBody PSWFProcRoleDTO pswfprocroledto) {
        PSWFProcRole pswfprocrole = pswfprocroledto.toDO();
    	pswfprocrole = pswfprocroleService.getDraft(pswfprocrole) ;
    	pswfprocroledto.fromDO(pswfprocrole);
        return ResponseEntity.status(HttpStatus.OK).body(pswfprocroledto);
    }

    @ApiOperation(value = "Remove", tags = {"PSWFProcRole" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/pswfprocroles/{pswfprocrole_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pswfprocrole_id") String pswfprocrole_id) {
        PSWFProcRoleDTO pswfprocroledto = new PSWFProcRoleDTO();
		PSWFProcRole domain = new PSWFProcRole();
		pswfprocroledto.setPSWFProcRoleId(pswfprocrole_id);
		domain.setPSWFProcRoleId(pswfprocrole_id);
        Boolean rst = pswfprocroleService.remove(domain.getPSWFProcRoleId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "CheckKey", tags = {"PSWFProcRole" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfprocroles/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSWFProcRoleDTO pswfprocroledto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Get", tags = {"PSWFProcRole" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfprocroles/{pswfprocrole_id}")
    public ResponseEntity<PSWFProcRoleDTO> get(@PathVariable("pswfprocrole_id") String pswfprocrole_id) {
        PSWFProcRoleDTO dto = new PSWFProcRoleDTO();
        PSWFProcRole domain = pswfprocroleService.get(pswfprocrole_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"PSWFProcRole" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfprocroles/{pswfprocrole_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSWFProcRoleDTO pswfprocroledto) {
        PSWFProcRole pswfprocrole = pswfprocroledto.toDO();
    	Boolean b = pswfprocroleService.save(pswfprocrole) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Update", tags = {"PSWFProcRole" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/pswfprocroles/{pswfprocrole_id}")
    @Transactional
    public ResponseEntity<PSWFProcRoleDTO> update(@PathVariable("pswfprocrole_id") String pswfprocrole_id, @RequestBody PSWFProcRoleDTO pswfprocroledto) {
		PSWFProcRole domain = pswfprocroledto.toDO();
        domain.setPSWFProcRoleId(pswfprocrole_id);
		pswfprocroleService.update(domain);
		PSWFProcRoleDTO dto = new PSWFProcRoleDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSWFProcRole" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pswfprocroles/fetchdefault")
	public ResponseEntity<Page<PSWFProcRoleDTO>> fetchDefault(PSWFProcRoleSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWFProcRoleDTO> list = new ArrayList<PSWFProcRoleDTO>();
        
        Page<PSWFProcRole> domains = pswfprocroleService.searchDefault(context) ;
        for(PSWFProcRole pswfprocrole : domains.getContent()){
            PSWFProcRoleDTO dto = new PSWFProcRoleDTO();
            dto.fromDO(pswfprocrole);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
