package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSWFProcessDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSWFProcess;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSWFProcessService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSWFProcessSearchContext;

@Api(tags = {"PSWFProcess" })
@RestController
@RequestMapping("")
public class PSWFProcessResource {

    @Autowired
    private IPSWFProcessService pswfprocessService;

    public IPSWFProcessService getPswfprocessService() {
        return this.pswfprocessService;
    }

    @ApiOperation(value = "CheckKey", tags = {"PSWFProcess" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfprocesses/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSWFProcessDTO pswfprocessdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Update", tags = {"PSWFProcess" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/pswfprocesses/{pswfprocess_id}")
    @Transactional
    public ResponseEntity<PSWFProcessDTO> update(@PathVariable("pswfprocess_id") String pswfprocess_id, @RequestBody PSWFProcessDTO pswfprocessdto) {
		PSWFProcess domain = pswfprocessdto.toDO();
        domain.setPSWFProcessId(pswfprocess_id);
		pswfprocessService.update(domain);
		PSWFProcessDTO dto = new PSWFProcessDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"PSWFProcess" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfprocesses/{pswfprocess_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSWFProcessDTO pswfprocessdto) {
        PSWFProcess pswfprocess = pswfprocessdto.toDO();
    	Boolean b = pswfprocessService.save(pswfprocess) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Remove", tags = {"PSWFProcess" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/pswfprocesses/{pswfprocess_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pswfprocess_id") String pswfprocess_id) {
        PSWFProcessDTO pswfprocessdto = new PSWFProcessDTO();
		PSWFProcess domain = new PSWFProcess();
		pswfprocessdto.setPSWFProcessId(pswfprocess_id);
		domain.setPSWFProcessId(pswfprocess_id);
        Boolean rst = pswfprocessService.remove(domain.getPSWFProcessId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "GetDraft", tags = {"PSWFProcess" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfprocesses/{pswfprocess_id}/getdraft")
    @Transactional
    public ResponseEntity<PSWFProcessDTO> getDraft(@PathVariable("pswfprocess_id") String pswfprocess_id, @RequestBody PSWFProcessDTO pswfprocessdto) {
        PSWFProcess pswfprocess = pswfprocessdto.toDO();
    	pswfprocess = pswfprocessService.getDraft(pswfprocess) ;
    	pswfprocessdto.fromDO(pswfprocess);
        return ResponseEntity.status(HttpStatus.OK).body(pswfprocessdto);
    }

    @ApiOperation(value = "Get", tags = {"PSWFProcess" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfprocesses/{pswfprocess_id}")
    public ResponseEntity<PSWFProcessDTO> get(@PathVariable("pswfprocess_id") String pswfprocess_id) {
        PSWFProcessDTO dto = new PSWFProcessDTO();
        PSWFProcess domain = pswfprocessService.get(pswfprocess_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Create", tags = {"PSWFProcess" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfprocesses")
    @Transactional
    public ResponseEntity<PSWFProcessDTO> create(@RequestBody PSWFProcessDTO pswfprocessdto) {
        PSWFProcessDTO dto = new PSWFProcessDTO();
        PSWFProcess domain = pswfprocessdto.toDO();
		pswfprocessService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSWFProcess" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pswfprocesses/fetchdefault")
	public ResponseEntity<Page<PSWFProcessDTO>> fetchDefault(PSWFProcessSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWFProcessDTO> list = new ArrayList<PSWFProcessDTO>();
        
        Page<PSWFProcess> domains = pswfprocessService.searchDefault(context) ;
        for(PSWFProcess pswfprocess : domains.getContent()){
            PSWFProcessDTO dto = new PSWFProcessDTO();
            dto.fromDO(pswfprocess);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
