package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSWFRoleDetailDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSWFRoleDetail;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSWFRoleDetailService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSWFRoleDetailSearchContext;

@Api(tags = {"PSWFRoleDetail" })
@RestController
@RequestMapping("")
public class PSWFRoleDetailResource {

    @Autowired
    private IPSWFRoleDetailService pswfroledetailService;

    public IPSWFRoleDetailService getPswfroledetailService() {
        return this.pswfroledetailService;
    }

    @ApiOperation(value = "Save", tags = {"PSWFRoleDetail" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfroledetails/{pswfroledetail_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSWFRoleDetailDTO pswfroledetaildto) {
        PSWFRoleDetail pswfroledetail = pswfroledetaildto.toDO();
    	Boolean b = pswfroledetailService.save(pswfroledetail) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Update", tags = {"PSWFRoleDetail" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/pswfroledetails/{pswfroledetail_id}")
    @Transactional
    public ResponseEntity<PSWFRoleDetailDTO> update(@PathVariable("pswfroledetail_id") String pswfroledetail_id, @RequestBody PSWFRoleDetailDTO pswfroledetaildto) {
		PSWFRoleDetail domain = pswfroledetaildto.toDO();
        domain.setPSWFRoleDetailId(pswfroledetail_id);
		pswfroledetailService.update(domain);
		PSWFRoleDetailDTO dto = new PSWFRoleDetailDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Get", tags = {"PSWFRoleDetail" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfroledetails/{pswfroledetail_id}")
    public ResponseEntity<PSWFRoleDetailDTO> get(@PathVariable("pswfroledetail_id") String pswfroledetail_id) {
        PSWFRoleDetailDTO dto = new PSWFRoleDetailDTO();
        PSWFRoleDetail domain = pswfroledetailService.get(pswfroledetail_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"PSWFRoleDetail" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfroledetails/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSWFRoleDetailDTO pswfroledetaildto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Create", tags = {"PSWFRoleDetail" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfroledetails")
    @Transactional
    public ResponseEntity<PSWFRoleDetailDTO> create(@RequestBody PSWFRoleDetailDTO pswfroledetaildto) {
        PSWFRoleDetailDTO dto = new PSWFRoleDetailDTO();
        PSWFRoleDetail domain = pswfroledetaildto.toDO();
		pswfroledetailService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"PSWFRoleDetail" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfroledetails/{pswfroledetail_id}/getdraft")
    @Transactional
    public ResponseEntity<PSWFRoleDetailDTO> getDraft(@PathVariable("pswfroledetail_id") String pswfroledetail_id, @RequestBody PSWFRoleDetailDTO pswfroledetaildto) {
        PSWFRoleDetail pswfroledetail = pswfroledetaildto.toDO();
    	pswfroledetail = pswfroledetailService.getDraft(pswfroledetail) ;
    	pswfroledetaildto.fromDO(pswfroledetail);
        return ResponseEntity.status(HttpStatus.OK).body(pswfroledetaildto);
    }

    @ApiOperation(value = "Remove", tags = {"PSWFRoleDetail" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/pswfroledetails/{pswfroledetail_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pswfroledetail_id") String pswfroledetail_id) {
        PSWFRoleDetailDTO pswfroledetaildto = new PSWFRoleDetailDTO();
		PSWFRoleDetail domain = new PSWFRoleDetail();
		pswfroledetaildto.setPSWFRoleDetailId(pswfroledetail_id);
		domain.setPSWFRoleDetailId(pswfroledetail_id);
        Boolean rst = pswfroledetailService.remove(domain.getPSWFRoleDetailId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSWFRoleDetail" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pswfroledetails/fetchdefault")
	public ResponseEntity<Page<PSWFRoleDetailDTO>> fetchDefault(PSWFRoleDetailSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWFRoleDetailDTO> list = new ArrayList<PSWFRoleDetailDTO>();
        
        Page<PSWFRoleDetail> domains = pswfroledetailService.searchDefault(context) ;
        for(PSWFRoleDetail pswfroledetail : domains.getContent()){
            PSWFRoleDetailDTO dto = new PSWFRoleDetailDTO();
            dto.fromDO(pswfroledetail);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}



    @ApiOperation(value = "Save", tags = {"PSWFRoleDetail" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfroles/{pswfrole_id}/pswfroledetails/save")
    public ResponseEntity<Boolean> saveByPSWFRole(@PathVariable("pswfrole_id") String pswfrole_id, @RequestBody PSWFRoleDetailDTO pswfroledetaildto) {
        PSWFRoleDetail domain = pswfroledetaildto.toDO();
        domain.setPSWFRoleId(pswfrole_id);
    	Boolean b = pswfroledetailService.save(domain) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Update", tags = {"PSWFRoleDetail" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/pswfroles/{pswfrole_id}/pswfroledetails/{pswfroledetail_id}")
    @Transactional
    public ResponseEntity<PSWFRoleDetailDTO> updateByPSWFRole(@PathVariable("pswfrole_id") String pswfrole_id, @PathVariable("pswfroledetail_id") String pswfroledetail_id, @RequestBody PSWFRoleDetailDTO pswfroledetaildto) {
		PSWFRoleDetail domain = pswfroledetaildto.toDO();
        domain.setPSWFRoleId(pswfrole_id);
        domain.setPSWFRoleDetailId(pswfroledetail_id);
		pswfroledetailService.update(domain);
		PSWFRoleDetailDTO dto = new PSWFRoleDetailDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Get", tags = {"PSWFRoleDetail" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfroles/{pswfrole_id}/pswfroledetails/{pswfroledetail_id}")
    public ResponseEntity<PSWFRoleDetailDTO> getByPSWFRole(@PathVariable("pswfrole_id") String pswfrole_id, @PathVariable("pswfroledetail_id") String pswfroledetail_id) {
        PSWFRoleDetailDTO dto = new PSWFRoleDetailDTO();
        PSWFRoleDetail domain = pswfroledetailService.get(pswfroledetail_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"PSWFRoleDetail" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfroles/{pswfrole_id}/pswfroledetails/checkkey")
    public ResponseEntity<Boolean> checkKeyByPSWFRole(@PathVariable("pswfrole_id") String pswfrole_id, @RequestBody PSWFRoleDetailDTO pswfroledetaildto) {

        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Create", tags = {"PSWFRoleDetail" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfroles/{pswfrole_id}/pswfroledetails")
    @Transactional
    public ResponseEntity<PSWFRoleDetailDTO> createByPSWFRole(@PathVariable("pswfrole_id") String pswfrole_id, @RequestBody PSWFRoleDetailDTO pswfroledetaildto) {
        PSWFRoleDetailDTO dto = new PSWFRoleDetailDTO();
        PSWFRoleDetail domain = pswfroledetaildto.toDO();
        domain.setPSWFRoleId(pswfrole_id);
		pswfroledetailService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"PSWFRoleDetail" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfroles/{pswfrole_id}/pswfroledetails/{pswfroledetailpswfroledetailid}/getdraft")
    @Transactional
    public ResponseEntity<PSWFRoleDetailDTO> getDraftByPSWFRole(@PathVariable("pswfrole_id") String pswfrole_id, @PathVariable("pswfroledetail_id") String pswfroledetail_id, @RequestBody PSWFRoleDetailDTO pswfroledetaildto) {
        PSWFRoleDetail pswfroledetail = pswfroledetaildto.toDO();
    	pswfroledetail = pswfroledetailService.getDraft(pswfroledetail) ;
    	pswfroledetaildto.fromDO(pswfroledetail);
        return ResponseEntity.status(HttpStatus.OK).body(pswfroledetaildto);
    }

    @ApiOperation(value = "Remove", tags = {"PSWFRoleDetail" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/pswfroles/{pswfrole_id}/pswfroledetails/{pswfroledetail_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPSWFRole(@PathVariable("pswfrole_id") String pswfrole_id, @PathVariable("pswfroledetail_id") String pswfroledetail_id) {
        PSWFRoleDetailDTO pswfroledetaildto = new PSWFRoleDetailDTO();
		PSWFRoleDetail domain = new PSWFRoleDetail();
		pswfroledetaildto.setPSWFRoleDetailId(pswfroledetail_id);
		domain.setPSWFRoleDetailId(pswfroledetail_id);
        Boolean rst = pswfroledetailService.remove(domain.getPSWFRoleDetailId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSWFRoleDetail" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pswfroles/{pswfrole_id}/pswfroledetails/fetchdefault")
	public ResponseEntity<Page<PSWFRoleDetailDTO>> fetchPSWFRoleDetailDefault(@PathVariable("pswfrole_id") String pswfrole_id,PSWFRoleDetailSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWFRoleDetailDTO> list = new ArrayList<PSWFRoleDetailDTO>();
        context.setN_pswfroleid_eq(pswfrole_id);
        Page<PSWFRoleDetail> domains = pswfroledetailService.searchDefault(context) ;
        for(PSWFRoleDetail pswfroledetail : domains.getContent()){
            PSWFRoleDetailDTO dto = new PSWFRoleDetailDTO();
            dto.fromDO(pswfroledetail);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
