package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSWFRoleDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSWFRole;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSWFRoleService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSWFRoleSearchContext;

@Api(tags = {"PSWFRole" })
@RestController
@RequestMapping("")
public class PSWFRoleResource {

    @Autowired
    private IPSWFRoleService pswfroleService;

    public IPSWFRoleService getPswfroleService() {
        return this.pswfroleService;
    }

    @ApiOperation(value = "CheckKey", tags = {"PSWFRole" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfroles/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSWFRoleDTO pswfroledto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Update", tags = {"PSWFRole" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/pswfroles/{pswfrole_id}")
    @Transactional
    public ResponseEntity<PSWFRoleDTO> update(@PathVariable("pswfrole_id") String pswfrole_id, @RequestBody PSWFRoleDTO pswfroledto) {
		PSWFRole domain = pswfroledto.toDO();
        domain.setPSWFRoleId(pswfrole_id);
		pswfroleService.update(domain);
		PSWFRoleDTO dto = new PSWFRoleDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Get", tags = {"PSWFRole" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfroles/{pswfrole_id}")
    public ResponseEntity<PSWFRoleDTO> get(@PathVariable("pswfrole_id") String pswfrole_id) {
        PSWFRoleDTO dto = new PSWFRoleDTO();
        PSWFRole domain = pswfroleService.get(pswfrole_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"PSWFRole" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfroles/{pswfrole_id}/getdraft")
    @Transactional
    public ResponseEntity<PSWFRoleDTO> getDraft(@PathVariable("pswfrole_id") String pswfrole_id, @RequestBody PSWFRoleDTO pswfroledto) {
        PSWFRole pswfrole = pswfroledto.toDO();
    	pswfrole = pswfroleService.getDraft(pswfrole) ;
    	pswfroledto.fromDO(pswfrole);
        return ResponseEntity.status(HttpStatus.OK).body(pswfroledto);
    }

    @ApiOperation(value = "Remove", tags = {"PSWFRole" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/pswfroles/{pswfrole_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pswfrole_id") String pswfrole_id) {
        PSWFRoleDTO pswfroledto = new PSWFRoleDTO();
		PSWFRole domain = new PSWFRole();
		pswfroledto.setPSWFRoleId(pswfrole_id);
		domain.setPSWFRoleId(pswfrole_id);
        Boolean rst = pswfroleService.remove(domain.getPSWFRoleId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Create", tags = {"PSWFRole" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfroles")
    @Transactional
    public ResponseEntity<PSWFRoleDTO> create(@RequestBody PSWFRoleDTO pswfroledto) {
        PSWFRoleDTO dto = new PSWFRoleDTO();
        PSWFRole domain = pswfroledto.toDO();
		pswfroleService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"PSWFRole" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfroles/{pswfrole_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSWFRoleDTO pswfroledto) {
        PSWFRole pswfrole = pswfroledto.toDO();
    	Boolean b = pswfroleService.save(pswfrole) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@ApiOperation(value = "获取当前组织", tags = {"PSWFRole" } ,notes = "获取当前组织")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pswfroles/fetchcurorg")
	public ResponseEntity<Page<PSWFRoleDTO>> fetchCurOrg(PSWFRoleSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWFRoleDTO> list = new ArrayList<PSWFRoleDTO>();
        
        Page<PSWFRole> domains = pswfroleService.searchCurOrg(context) ;
        for(PSWFRole pswfrole : domains.getContent()){
            PSWFRoleDTO dto = new PSWFRoleDTO();
            dto.fromDO(pswfrole);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}

	@ApiOperation(value = "获取当前部门", tags = {"PSWFRole" } ,notes = "获取当前部门")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pswfroles/fetchcurorgdept")
	public ResponseEntity<Page<PSWFRoleDTO>> fetchCurOrgDept(PSWFRoleSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWFRoleDTO> list = new ArrayList<PSWFRoleDTO>();
        
        Page<PSWFRole> domains = pswfroleService.searchCurOrgDept(context) ;
        for(PSWFRole pswfrole : domains.getContent()){
            PSWFRoleDTO dto = new PSWFRoleDTO();
            dto.fromDO(pswfrole);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}

	@ApiOperation(value = "获取DEFAULT", tags = {"PSWFRole" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pswfroles/fetchdefault")
	public ResponseEntity<Page<PSWFRoleDTO>> fetchDefault(PSWFRoleSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWFRoleDTO> list = new ArrayList<PSWFRoleDTO>();
        
        Page<PSWFRole> domains = pswfroleService.searchDefault(context) ;
        for(PSWFRole pswfrole : domains.getContent()){
            PSWFRoleDTO dto = new PSWFRoleDTO();
            dto.fromDO(pswfrole);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
