package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSWFVersionDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSWFVersion;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSWFVersionService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSWFVersionSearchContext;

@Api(tags = {"PSWFVersion" })
@RestController
@RequestMapping("")
public class PSWFVersionResource {

    @Autowired
    private IPSWFVersionService pswfversionService;

    public IPSWFVersionService getPswfversionService() {
        return this.pswfversionService;
    }

    @ApiOperation(value = "CheckKey", tags = {"PSWFVersion" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfversions/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSWFVersionDTO pswfversiondto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraft", tags = {"PSWFVersion" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfversions/{pswfversion_id}/getdraft")
    @Transactional
    public ResponseEntity<PSWFVersionDTO> getDraft(@PathVariable("pswfversion_id") String pswfversion_id, @RequestBody PSWFVersionDTO pswfversiondto) {
        PSWFVersion pswfversion = pswfversiondto.toDO();
    	pswfversion = pswfversionService.getDraft(pswfversion) ;
    	pswfversiondto.fromDO(pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversiondto);
    }

    @ApiOperation(value = "Update", tags = {"PSWFVersion" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/pswfversions/{pswfversion_id}")
    @Transactional
    public ResponseEntity<PSWFVersionDTO> update(@PathVariable("pswfversion_id") String pswfversion_id, @RequestBody PSWFVersionDTO pswfversiondto) {
		PSWFVersion domain = pswfversiondto.toDO();
        domain.setPSWFVersionId(pswfversion_id);
		pswfversionService.update(domain);
		PSWFVersionDTO dto = new PSWFVersionDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Get", tags = {"PSWFVersion" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/pswfversions/{pswfversion_id}")
    public ResponseEntity<PSWFVersionDTO> get(@PathVariable("pswfversion_id") String pswfversion_id) {
        PSWFVersionDTO dto = new PSWFVersionDTO();
        PSWFVersion domain = pswfversionService.get(pswfversion_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Create", tags = {"PSWFVersion" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfversions")
    @Transactional
    public ResponseEntity<PSWFVersionDTO> create(@RequestBody PSWFVersionDTO pswfversiondto) {
        PSWFVersionDTO dto = new PSWFVersionDTO();
        PSWFVersion domain = pswfversiondto.toDO();
		pswfversionService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"PSWFVersion" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/pswfversions/{pswfversion_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("pswfversion_id") String pswfversion_id) {
        PSWFVersionDTO pswfversiondto = new PSWFVersionDTO();
		PSWFVersion domain = new PSWFVersion();
		pswfversiondto.setPSWFVersionId(pswfversion_id);
		domain.setPSWFVersionId(pswfversion_id);
        Boolean rst = pswfversionService.remove(domain.getPSWFVersionId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Save", tags = {"PSWFVersion" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/pswfversions/{pswfversion_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSWFVersionDTO pswfversiondto) {
        PSWFVersion pswfversion = pswfversiondto.toDO();
    	Boolean b = pswfversionService.save(pswfversion) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSWFVersion" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/pswfversions/fetchdefault")
	public ResponseEntity<Page<PSWFVersionDTO>> fetchDefault(PSWFVersionSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWFVersionDTO> list = new ArrayList<PSWFVersionDTO>();
        
        Page<PSWFVersion> domains = pswfversionService.searchDefault(context) ;
        for(PSWFVersion pswfversion : domains.getContent()){
            PSWFVersionDTO dto = new PSWFVersionDTO();
            dto.fromDO(pswfversion);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}



    @ApiOperation(value = "CheckKey", tags = {"PSWFVersion" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psworkflows/{psworkflow_id}/pswfversions/checkkey")
    public ResponseEntity<Boolean> checkKeyByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSWFVersionDTO pswfversiondto) {

        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraft", tags = {"PSWFVersion" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/psworkflows/{psworkflow_id}/pswfversions/{pswfversionpswfversionid}/getdraft")
    @Transactional
    public ResponseEntity<PSWFVersionDTO> getDraftByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("pswfversion_id") String pswfversion_id, @RequestBody PSWFVersionDTO pswfversiondto) {
        PSWFVersion pswfversion = pswfversiondto.toDO();
    	pswfversion = pswfversionService.getDraft(pswfversion) ;
    	pswfversiondto.fromDO(pswfversion);
        return ResponseEntity.status(HttpStatus.OK).body(pswfversiondto);
    }

    @ApiOperation(value = "Update", tags = {"PSWFVersion" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/psworkflows/{psworkflow_id}/pswfversions/{pswfversion_id}")
    @Transactional
    public ResponseEntity<PSWFVersionDTO> updateByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("pswfversion_id") String pswfversion_id, @RequestBody PSWFVersionDTO pswfversiondto) {
		PSWFVersion domain = pswfversiondto.toDO();
        domain.setPSWorkflowId(psworkflow_id);
        domain.setPSWFVersionId(pswfversion_id);
		pswfversionService.update(domain);
		PSWFVersionDTO dto = new PSWFVersionDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Get", tags = {"PSWFVersion" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/psworkflows/{psworkflow_id}/pswfversions/{pswfversion_id}")
    public ResponseEntity<PSWFVersionDTO> getByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("pswfversion_id") String pswfversion_id) {
        PSWFVersionDTO dto = new PSWFVersionDTO();
        PSWFVersion domain = pswfversionService.get(pswfversion_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Create", tags = {"PSWFVersion" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psworkflows/{psworkflow_id}/pswfversions")
    @Transactional
    public ResponseEntity<PSWFVersionDTO> createByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSWFVersionDTO pswfversiondto) {
        PSWFVersionDTO dto = new PSWFVersionDTO();
        PSWFVersion domain = pswfversiondto.toDO();
        domain.setPSWorkflowId(psworkflow_id);
		pswfversionService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"PSWFVersion" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/psworkflows/{psworkflow_id}/pswfversions/{pswfversion_id}")
    @Transactional
    public ResponseEntity<Boolean> removeByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @PathVariable("pswfversion_id") String pswfversion_id) {
        PSWFVersionDTO pswfversiondto = new PSWFVersionDTO();
		PSWFVersion domain = new PSWFVersion();
		pswfversiondto.setPSWFVersionId(pswfversion_id);
		domain.setPSWFVersionId(pswfversion_id);
        Boolean rst = pswfversionService.remove(domain.getPSWFVersionId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Save", tags = {"PSWFVersion" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psworkflows/{psworkflow_id}/pswfversions/save")
    public ResponseEntity<Boolean> saveByPSWorkflow(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSWFVersionDTO pswfversiondto) {
        PSWFVersion domain = pswfversiondto.toDO();
        domain.setPSWorkflowId(psworkflow_id);
    	Boolean b = pswfversionService.save(domain) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"PSWFVersion" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/psworkflows/{psworkflow_id}/pswfversions/fetchdefault")
	public ResponseEntity<Page<PSWFVersionDTO>> fetchPSWFVersionDefault(@PathVariable("psworkflow_id") String psworkflow_id,PSWFVersionSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWFVersionDTO> list = new ArrayList<PSWFVersionDTO>();
        context.setN_psworkflowid_eq(psworkflow_id);
        Page<PSWFVersion> domains = pswfversionService.searchDefault(context) ;
        for(PSWFVersion pswfversion : domains.getContent()){
            PSWFVersionDTO dto = new PSWFVersionDTO();
            dto.fromDO(pswfversion);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
