package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.PSWorkflowDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.PSWorkflow;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IPSWorkflowService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.PSWorkflowSearchContext;

@Api(tags = {"PSWorkflow" })
@RestController
@RequestMapping("")
public class PSWorkflowResource {

    @Autowired
    private IPSWorkflowService psworkflowService;

    public IPSWorkflowService getPsworkflowService() {
        return this.psworkflowService;
    }

    @ApiOperation(value = "Save", tags = {"PSWorkflow" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psworkflows/{psworkflow_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody PSWorkflowDTO psworkflowdto) {
        PSWorkflow psworkflow = psworkflowdto.toDO();
    	Boolean b = psworkflowService.save(psworkflow) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Remove", tags = {"PSWorkflow" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/psworkflows/{psworkflow_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("psworkflow_id") String psworkflow_id) {
        PSWorkflowDTO psworkflowdto = new PSWorkflowDTO();
		PSWorkflow domain = new PSWorkflow();
		psworkflowdto.setPSWorkflowId(psworkflow_id);
		domain.setPSWorkflowId(psworkflow_id);
        Boolean rst = psworkflowService.remove(domain.getPSWorkflowId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Update", tags = {"PSWorkflow" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/psworkflows/{psworkflow_id}")
    @Transactional
    public ResponseEntity<PSWorkflowDTO> update(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSWorkflowDTO psworkflowdto) {
		PSWorkflow domain = psworkflowdto.toDO();
        domain.setPSWorkflowId(psworkflow_id);
		psworkflowService.update(domain);
		PSWorkflowDTO dto = new PSWorkflowDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"PSWorkflow" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psworkflows/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody PSWorkflowDTO psworkflowdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Create", tags = {"PSWorkflow" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/psworkflows")
    @Transactional
    public ResponseEntity<PSWorkflowDTO> create(@RequestBody PSWorkflowDTO psworkflowdto) {
        PSWorkflowDTO dto = new PSWorkflowDTO();
        PSWorkflow domain = psworkflowdto.toDO();
		psworkflowService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"PSWorkflow" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/psworkflows/{psworkflow_id}/getdraft")
    @Transactional
    public ResponseEntity<PSWorkflowDTO> getDraft(@PathVariable("psworkflow_id") String psworkflow_id, @RequestBody PSWorkflowDTO psworkflowdto) {
        PSWorkflow psworkflow = psworkflowdto.toDO();
    	psworkflow = psworkflowService.getDraft(psworkflow) ;
    	psworkflowdto.fromDO(psworkflow);
        return ResponseEntity.status(HttpStatus.OK).body(psworkflowdto);
    }

    @ApiOperation(value = "Get", tags = {"PSWorkflow" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/psworkflows/{psworkflow_id}")
    public ResponseEntity<PSWorkflowDTO> get(@PathVariable("psworkflow_id") String psworkflow_id) {
        PSWorkflowDTO dto = new PSWorkflowDTO();
        PSWorkflow domain = psworkflowService.get(psworkflow_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取当前组织", tags = {"PSWorkflow" } ,notes = "获取当前组织")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/psworkflows/fetchcurorg")
	public ResponseEntity<Page<PSWorkflowDTO>> fetchCurOrg(PSWorkflowSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWorkflowDTO> list = new ArrayList<PSWorkflowDTO>();
        
        Page<PSWorkflow> domains = psworkflowService.searchCurOrg(context) ;
        for(PSWorkflow psworkflow : domains.getContent()){
            PSWorkflowDTO dto = new PSWorkflowDTO();
            dto.fromDO(psworkflow);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}

	@ApiOperation(value = "获取当前部门", tags = {"PSWorkflow" } ,notes = "获取当前部门")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/psworkflows/fetchcurorgdept")
	public ResponseEntity<Page<PSWorkflowDTO>> fetchCurOrgDept(PSWorkflowSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWorkflowDTO> list = new ArrayList<PSWorkflowDTO>();
        
        Page<PSWorkflow> domains = psworkflowService.searchCurOrgDept(context) ;
        for(PSWorkflow psworkflow : domains.getContent()){
            PSWorkflowDTO dto = new PSWorkflowDTO();
            dto.fromDO(psworkflow);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}

	@ApiOperation(value = "获取DEFAULT", tags = {"PSWorkflow" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/psworkflows/fetchdefault")
	public ResponseEntity<Page<PSWorkflowDTO>> fetchDefault(PSWorkflowSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<PSWorkflowDTO> list = new ArrayList<PSWorkflowDTO>();
        
        Page<PSWorkflow> domains = psworkflowService.searchDefault(context) ;
        for(PSWorkflow psworkflow : domains.getContent()){
            PSWorkflowDTO dto = new PSWorkflowDTO();
            dto.fromDO(psworkflow);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
