package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.WFAppDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.WFApp;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWFAppService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WFAppSearchContext;

@Api(tags = {"WFApp" })
@RestController
@RequestMapping("")
public class WFAppResource {

    @Autowired
    private IWFAppService wfappService;

    public IWFAppService getWfappService() {
        return this.wfappService;
    }

    @ApiOperation(value = "CheckKey", tags = {"WFApp" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfapps/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFAppDTO wfappdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraft", tags = {"WFApp" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfapps/{wfapp_id}/getdraft")
    @Transactional
    public ResponseEntity<WFAppDTO> getDraft(@PathVariable("wfapp_id") String wfapp_id, @RequestBody WFAppDTO wfappdto) {
        WFApp wfapp = wfappdto.toDO();
    	wfapp = wfappService.getDraft(wfapp) ;
    	wfappdto.fromDO(wfapp);
        return ResponseEntity.status(HttpStatus.OK).body(wfappdto);
    }

    @ApiOperation(value = "Update", tags = {"WFApp" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/wfapps/{wfapp_id}")
    @Transactional
    public ResponseEntity<WFAppDTO> update(@PathVariable("wfapp_id") String wfapp_id, @RequestBody WFAppDTO wfappdto) {
		WFApp domain = wfappdto.toDO();
        domain.setWFAppId(wfapp_id);
		wfappService.update(domain);
		WFAppDTO dto = new WFAppDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"WFApp" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfapps/{wfapp_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody WFAppDTO wfappdto) {
        WFApp wfapp = wfappdto.toDO();
    	Boolean b = wfappService.save(wfapp) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Get", tags = {"WFApp" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfapps/{wfapp_id}")
    public ResponseEntity<WFAppDTO> get(@PathVariable("wfapp_id") String wfapp_id) {
        WFAppDTO dto = new WFAppDTO();
        WFApp domain = wfappService.get(wfapp_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"WFApp" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/wfapps/{wfapp_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("wfapp_id") String wfapp_id) {
        WFAppDTO wfappdto = new WFAppDTO();
		WFApp domain = new WFApp();
		wfappdto.setWFAppId(wfapp_id);
		domain.setWFAppId(wfapp_id);
        Boolean rst = wfappService.remove(domain.getWFAppId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Create", tags = {"WFApp" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfapps")
    @Transactional
    public ResponseEntity<WFAppDTO> create(@RequestBody WFAppDTO wfappdto) {
        WFAppDTO dto = new WFAppDTO();
        WFApp domain = wfappdto.toDO();
		wfappService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"WFApp" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfapps/fetchdefault")
	public ResponseEntity<Page<WFAppDTO>> fetchDefault(WFAppSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFAppDTO> list = new ArrayList<WFAppDTO>();
        
        Page<WFApp> domains = wfappService.searchDefault(context) ;
        for(WFApp wfapp : domains.getContent()){
            WFAppDTO dto = new WFAppDTO();
            dto.fromDO(wfapp);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
