package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.WFEngineDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.WFEngine;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWFEngineService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WFEngineSearchContext;

@Api(tags = {"WFEngine" })
@RestController
@RequestMapping("")
public class WFEngineResource {

    @Autowired
    private IWFEngineService wfengineService;

    public IWFEngineService getWfengineService() {
        return this.wfengineService;
    }

    @ApiOperation(value = "GetDraft", tags = {"WFEngine" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfengines/{wfengine_id}/getdraft")
    @Transactional
    public ResponseEntity<WFEngineDTO> getDraft(@PathVariable("wfengine_id") String wfengine_id, @RequestBody WFEngineDTO wfenginedto) {
        WFEngine wfengine = wfenginedto.toDO();
    	wfengine = wfengineService.getDraft(wfengine) ;
    	wfenginedto.fromDO(wfengine);
        return ResponseEntity.status(HttpStatus.OK).body(wfenginedto);
    }

    @ApiOperation(value = "CheckKey", tags = {"WFEngine" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfengines/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFEngineDTO wfenginedto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Update", tags = {"WFEngine" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/wfengines/{wfengine_id}")
    @Transactional
    public ResponseEntity<WFEngineDTO> update(@PathVariable("wfengine_id") String wfengine_id, @RequestBody WFEngineDTO wfenginedto) {
		WFEngine domain = wfenginedto.toDO();
        domain.setWFEngineId(wfengine_id);
		wfengineService.update(domain);
		WFEngineDTO dto = new WFEngineDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"WFEngine" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/wfengines/{wfengine_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("wfengine_id") String wfengine_id) {
        WFEngineDTO wfenginedto = new WFEngineDTO();
		WFEngine domain = new WFEngine();
		wfenginedto.setWFEngineId(wfengine_id);
		domain.setWFEngineId(wfengine_id);
        Boolean rst = wfengineService.remove(domain.getWFEngineId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Create", tags = {"WFEngine" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfengines")
    @Transactional
    public ResponseEntity<WFEngineDTO> create(@RequestBody WFEngineDTO wfenginedto) {
        WFEngineDTO dto = new WFEngineDTO();
        WFEngine domain = wfenginedto.toDO();
		wfengineService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"WFEngine" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfengines/{wfengine_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody WFEngineDTO wfenginedto) {
        WFEngine wfengine = wfenginedto.toDO();
    	Boolean b = wfengineService.save(wfengine) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Get", tags = {"WFEngine" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfengines/{wfengine_id}")
    public ResponseEntity<WFEngineDTO> get(@PathVariable("wfengine_id") String wfengine_id) {
        WFEngineDTO dto = new WFEngineDTO();
        WFEngine domain = wfengineService.get(wfengine_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"WFEngine" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfengines/fetchdefault")
	public ResponseEntity<Page<WFEngineDTO>> fetchDefault(WFEngineSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFEngineDTO> list = new ArrayList<WFEngineDTO>();
        
        Page<WFEngine> domains = wfengineService.searchDefault(context) ;
        for(WFEngine wfengine : domains.getContent()){
            WFEngineDTO dto = new WFEngineDTO();
            dto.fromDO(wfengine);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
