package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.WFInstanceDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.WFInstance;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWFInstanceService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WFInstanceSearchContext;

@Api(tags = {"WFInstance" })
@RestController
@RequestMapping("")
public class WFInstanceResource {

    @Autowired
    private IWFInstanceService wfinstanceService;

    public IWFInstanceService getWfinstanceService() {
        return this.wfinstanceService;
    }

    @ApiOperation(value = "Get", tags = {"WFInstance" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfinstances/{wfinstance_id}")
    public ResponseEntity<WFInstanceDTO> get(@PathVariable("wfinstance_id") String wfinstance_id) {
        WFInstanceDTO dto = new WFInstanceDTO();
        WFInstance domain = wfinstanceService.get(wfinstance_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"WFInstance" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfinstances/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFInstanceDTO wfinstancedto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Remove", tags = {"WFInstance" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/wfinstances/{wfinstance_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("wfinstance_id") String wfinstance_id) {
        WFInstanceDTO wfinstancedto = new WFInstanceDTO();
		WFInstance domain = new WFInstance();
		wfinstancedto.setWFInstanceId(wfinstance_id);
		domain.setWFInstanceId(wfinstance_id);
        Boolean rst = wfinstanceService.remove(domain.getWFInstanceId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Create", tags = {"WFInstance" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfinstances")
    @Transactional
    public ResponseEntity<WFInstanceDTO> create(@RequestBody WFInstanceDTO wfinstancedto) {
        WFInstanceDTO dto = new WFInstanceDTO();
        WFInstance domain = wfinstancedto.toDO();
		wfinstanceService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"WFInstance" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfinstances/{wfinstance_id}/getdraft")
    @Transactional
    public ResponseEntity<WFInstanceDTO> getDraft(@PathVariable("wfinstance_id") String wfinstance_id, @RequestBody WFInstanceDTO wfinstancedto) {
        WFInstance wfinstance = wfinstancedto.toDO();
    	wfinstance = wfinstanceService.getDraft(wfinstance) ;
    	wfinstancedto.fromDO(wfinstance);
        return ResponseEntity.status(HttpStatus.OK).body(wfinstancedto);
    }

    @ApiOperation(value = "Save", tags = {"WFInstance" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfinstances/{wfinstance_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody WFInstanceDTO wfinstancedto) {
        WFInstance wfinstance = wfinstancedto.toDO();
    	Boolean b = wfinstanceService.save(wfinstance) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Update", tags = {"WFInstance" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/wfinstances/{wfinstance_id}")
    @Transactional
    public ResponseEntity<WFInstanceDTO> update(@PathVariable("wfinstance_id") String wfinstance_id, @RequestBody WFInstanceDTO wfinstancedto) {
		WFInstance domain = wfinstancedto.toDO();
        domain.setWFInstanceId(wfinstance_id);
		wfinstanceService.update(domain);
		WFInstanceDTO dto = new WFInstanceDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"WFInstance" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfinstances/fetchdefault")
	public ResponseEntity<Page<WFInstanceDTO>> fetchDefault(WFInstanceSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFInstanceDTO> list = new ArrayList<WFInstanceDTO>();
        
        Page<WFInstance> domains = wfinstanceService.searchDefault(context) ;
        for(WFInstance wfinstance : domains.getContent()){
            WFInstanceDTO dto = new WFInstanceDTO();
            dto.fromDO(wfinstance);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
