package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.WFModeDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.WFMode;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWFModeService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WFModeSearchContext;

@Api(tags = {"WFMode" })
@RestController
@RequestMapping("")
public class WFModeResource {

    @Autowired
    private IWFModeService wfmodeService;

    public IWFModeService getWfmodeService() {
        return this.wfmodeService;
    }

    @ApiOperation(value = "CheckKey", tags = {"WFMode" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfmodes/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFModeDTO wfmodedto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Remove", tags = {"WFMode" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/wfmodes/{wfmode_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("wfmode_id") String wfmode_id) {
        WFModeDTO wfmodedto = new WFModeDTO();
		WFMode domain = new WFMode();
		wfmodedto.setWFModeId(wfmode_id);
		domain.setWFModeId(wfmode_id);
        Boolean rst = wfmodeService.remove(domain.getWFModeId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Get", tags = {"WFMode" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfmodes/{wfmode_id}")
    public ResponseEntity<WFModeDTO> get(@PathVariable("wfmode_id") String wfmode_id) {
        WFModeDTO dto = new WFModeDTO();
        WFMode domain = wfmodeService.get(wfmode_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Update", tags = {"WFMode" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/wfmodes/{wfmode_id}")
    @Transactional
    public ResponseEntity<WFModeDTO> update(@PathVariable("wfmode_id") String wfmode_id, @RequestBody WFModeDTO wfmodedto) {
		WFMode domain = wfmodedto.toDO();
        domain.setWFModeId(wfmode_id);
		wfmodeService.update(domain);
		WFModeDTO dto = new WFModeDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"WFMode" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfmodes/{wfmode_id}/getdraft")
    @Transactional
    public ResponseEntity<WFModeDTO> getDraft(@PathVariable("wfmode_id") String wfmode_id, @RequestBody WFModeDTO wfmodedto) {
        WFMode wfmode = wfmodedto.toDO();
    	wfmode = wfmodeService.getDraft(wfmode) ;
    	wfmodedto.fromDO(wfmode);
        return ResponseEntity.status(HttpStatus.OK).body(wfmodedto);
    }

    @ApiOperation(value = "Save", tags = {"WFMode" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfmodes/{wfmode_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody WFModeDTO wfmodedto) {
        WFMode wfmode = wfmodedto.toDO();
    	Boolean b = wfmodeService.save(wfmode) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Create", tags = {"WFMode" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfmodes")
    @Transactional
    public ResponseEntity<WFModeDTO> create(@RequestBody WFModeDTO wfmodedto) {
        WFModeDTO dto = new WFModeDTO();
        WFMode domain = wfmodedto.toDO();
		wfmodeService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"WFMode" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfmodes/fetchdefault")
	public ResponseEntity<Page<WFModeDTO>> fetchDefault(WFModeSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFModeDTO> list = new ArrayList<WFModeDTO>();
        
        Page<WFMode> domains = wfmodeService.searchDefault(context) ;
        for(WFMode wfmode : domains.getContent()){
            WFModeDTO dto = new WFModeDTO();
            dto.fromDO(wfmode);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
