package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.WFRoleDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.WFRole;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWFRoleService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WFRoleSearchContext;

@Api(tags = {"WFRole" })
@RestController
@RequestMapping("")
public class WFRoleResource {

    @Autowired
    private IWFRoleService wfroleService;

    public IWFRoleService getWfroleService() {
        return this.wfroleService;
    }

    @ApiOperation(value = "GetDraft", tags = {"WFRole" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfroles/{wfrole_id}/getdraft")
    @Transactional
    public ResponseEntity<WFRoleDTO> getDraft(@PathVariable("wfrole_id") String wfrole_id, @RequestBody WFRoleDTO wfroledto) {
        WFRole wfrole = wfroledto.toDO();
    	wfrole = wfroleService.getDraft(wfrole) ;
    	wfroledto.fromDO(wfrole);
        return ResponseEntity.status(HttpStatus.OK).body(wfroledto);
    }

    @ApiOperation(value = "Get", tags = {"WFRole" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfroles/{wfrole_id}")
    public ResponseEntity<WFRoleDTO> get(@PathVariable("wfrole_id") String wfrole_id) {
        WFRoleDTO dto = new WFRoleDTO();
        WFRole domain = wfroleService.get(wfrole_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Create", tags = {"WFRole" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfroles")
    @Transactional
    public ResponseEntity<WFRoleDTO> create(@RequestBody WFRoleDTO wfroledto) {
        WFRoleDTO dto = new WFRoleDTO();
        WFRole domain = wfroledto.toDO();
		wfroleService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"WFRole" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/wfroles/{wfrole_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("wfrole_id") String wfrole_id) {
        WFRoleDTO wfroledto = new WFRoleDTO();
		WFRole domain = new WFRole();
		wfroledto.setWFRoleId(wfrole_id);
		domain.setWFRoleId(wfrole_id);
        Boolean rst = wfroleService.remove(domain.getWFRoleId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Update", tags = {"WFRole" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/wfroles/{wfrole_id}")
    @Transactional
    public ResponseEntity<WFRoleDTO> update(@PathVariable("wfrole_id") String wfrole_id, @RequestBody WFRoleDTO wfroledto) {
		WFRole domain = wfroledto.toDO();
        domain.setWFRoleId(wfrole_id);
		wfroleService.update(domain);
		WFRoleDTO dto = new WFRoleDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"WFRole" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfroles/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFRoleDTO wfroledto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Save", tags = {"WFRole" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfroles/{wfrole_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody WFRoleDTO wfroledto) {
        WFRole wfrole = wfroledto.toDO();
    	Boolean b = wfroleService.save(wfrole) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"WFRole" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfroles/fetchdefault")
	public ResponseEntity<Page<WFRoleDTO>> fetchDefault(WFRoleSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFRoleDTO> list = new ArrayList<WFRoleDTO>();
        
        Page<WFRole> domains = wfroleService.searchDefault(context) ;
        for(WFRole wfrole : domains.getContent()){
            WFRoleDTO dto = new WFRoleDTO();
            dto.fromDO(wfrole);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
