package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.WFStepActorDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.WFStepActor;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWFStepActorService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WFStepActorSearchContext;

@Api(tags = {"WFStepActor" })
@RestController
@RequestMapping("")
public class WFStepActorResource {

    @Autowired
    private IWFStepActorService wfstepactorService;

    public IWFStepActorService getWfstepactorService() {
        return this.wfstepactorService;
    }

    @ApiOperation(value = "CheckKey", tags = {"WFStepActor" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfstepactors/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFStepActorDTO wfstepactordto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Get", tags = {"WFStepActor" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfstepactors/{wfstepactor_id}")
    public ResponseEntity<WFStepActorDTO> get(@PathVariable("wfstepactor_id") String wfstepactor_id) {
        WFStepActorDTO dto = new WFStepActorDTO();
        WFStepActor domain = wfstepactorService.get(wfstepactor_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Create", tags = {"WFStepActor" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfstepactors")
    @Transactional
    public ResponseEntity<WFStepActorDTO> create(@RequestBody WFStepActorDTO wfstepactordto) {
        WFStepActorDTO dto = new WFStepActorDTO();
        WFStepActor domain = wfstepactordto.toDO();
		wfstepactorService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"WFStepActor" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/wfstepactors/{wfstepactor_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("wfstepactor_id") String wfstepactor_id) {
        WFStepActorDTO wfstepactordto = new WFStepActorDTO();
		WFStepActor domain = new WFStepActor();
		wfstepactordto.setWFStepActorId(wfstepactor_id);
		domain.setWFStepActorId(wfstepactor_id);
        Boolean rst = wfstepactorService.remove(domain.getWFStepActorId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Save", tags = {"WFStepActor" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfstepactors/{wfstepactor_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody WFStepActorDTO wfstepactordto) {
        WFStepActor wfstepactor = wfstepactordto.toDO();
    	Boolean b = wfstepactorService.save(wfstepactor) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Update", tags = {"WFStepActor" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/wfstepactors/{wfstepactor_id}")
    @Transactional
    public ResponseEntity<WFStepActorDTO> update(@PathVariable("wfstepactor_id") String wfstepactor_id, @RequestBody WFStepActorDTO wfstepactordto) {
		WFStepActor domain = wfstepactordto.toDO();
        domain.setWFStepActorId(wfstepactor_id);
		wfstepactorService.update(domain);
		WFStepActorDTO dto = new WFStepActorDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "GetDraft", tags = {"WFStepActor" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfstepactors/{wfstepactor_id}/getdraft")
    @Transactional
    public ResponseEntity<WFStepActorDTO> getDraft(@PathVariable("wfstepactor_id") String wfstepactor_id, @RequestBody WFStepActorDTO wfstepactordto) {
        WFStepActor wfstepactor = wfstepactordto.toDO();
    	wfstepactor = wfstepactorService.getDraft(wfstepactor) ;
    	wfstepactordto.fromDO(wfstepactor);
        return ResponseEntity.status(HttpStatus.OK).body(wfstepactordto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"WFStepActor" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfstepactors/fetchdefault")
	public ResponseEntity<Page<WFStepActorDTO>> fetchDefault(WFStepActorSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFStepActorDTO> list = new ArrayList<WFStepActorDTO>();
        
        Page<WFStepActor> domains = wfstepactorService.searchDefault(context) ;
        for(WFStepActor wfstepactor : domains.getContent()){
            WFStepActorDTO dto = new WFStepActorDTO();
            dto.fromDO(wfstepactor);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
