package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.WFStepDataDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.WFStepData;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWFStepDataService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WFStepDataSearchContext;

@Api(tags = {"WFStepData" })
@RestController
@RequestMapping("")
public class WFStepDataResource {

    @Autowired
    private IWFStepDataService wfstepdataService;

    public IWFStepDataService getWfstepdataService() {
        return this.wfstepdataService;
    }

    @ApiOperation(value = "Create", tags = {"WFStepData" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfstepdata")
    @Transactional
    public ResponseEntity<WFStepDataDTO> create(@RequestBody WFStepDataDTO wfstepdatadto) {
        WFStepDataDTO dto = new WFStepDataDTO();
        WFStepData domain = wfstepdatadto.toDO();
		wfstepdataService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Get", tags = {"WFStepData" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfstepdata/{wfstepdata_id}")
    public ResponseEntity<WFStepDataDTO> get(@PathVariable("wfstepdata_id") String wfstepdata_id) {
        WFStepDataDTO dto = new WFStepDataDTO();
        WFStepData domain = wfstepdataService.get(wfstepdata_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"WFStepData" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfstepdata/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFStepDataDTO wfstepdatadto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Update", tags = {"WFStepData" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/wfstepdata/{wfstepdata_id}")
    @Transactional
    public ResponseEntity<WFStepDataDTO> update(@PathVariable("wfstepdata_id") String wfstepdata_id, @RequestBody WFStepDataDTO wfstepdatadto) {
		WFStepData domain = wfstepdatadto.toDO();
        domain.setWFStepDataId(wfstepdata_id);
		wfstepdataService.update(domain);
		WFStepDataDTO dto = new WFStepDataDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"WFStepData" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/wfstepdata/{wfstepdata_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("wfstepdata_id") String wfstepdata_id) {
        WFStepDataDTO wfstepdatadto = new WFStepDataDTO();
		WFStepData domain = new WFStepData();
		wfstepdatadto.setWFStepDataId(wfstepdata_id);
		domain.setWFStepDataId(wfstepdata_id);
        Boolean rst = wfstepdataService.remove(domain.getWFStepDataId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "GetDraft", tags = {"WFStepData" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfstepdata/{wfstepdata_id}/getdraft")
    @Transactional
    public ResponseEntity<WFStepDataDTO> getDraft(@PathVariable("wfstepdata_id") String wfstepdata_id, @RequestBody WFStepDataDTO wfstepdatadto) {
        WFStepData wfstepdata = wfstepdatadto.toDO();
    	wfstepdata = wfstepdataService.getDraft(wfstepdata) ;
    	wfstepdatadto.fromDO(wfstepdata);
        return ResponseEntity.status(HttpStatus.OK).body(wfstepdatadto);
    }

    @ApiOperation(value = "Save", tags = {"WFStepData" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfstepdata/{wfstepdata_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody WFStepDataDTO wfstepdatadto) {
        WFStepData wfstepdata = wfstepdatadto.toDO();
    	Boolean b = wfstepdataService.save(wfstepdata) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

	@ApiOperation(value = "获取ByBswfdata", tags = {"WFStepData" } ,notes = "获取ByBswfdata")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfstepdata/fetchbybswfdata")
	public ResponseEntity<Page<WFStepDataDTO>> fetchByBswfdata(WFStepDataSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFStepDataDTO> list = new ArrayList<WFStepDataDTO>();
        
        Page<WFStepData> domains = wfstepdataService.searchByBswfdata(context) ;
        for(WFStepData wfstepdata : domains.getContent()){
            WFStepDataDTO dto = new WFStepDataDTO();
            dto.fromDO(wfstepdata);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}

	@ApiOperation(value = "获取ByBsdata", tags = {"WFStepData" } ,notes = "获取ByBsdata")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfstepdata/fetchbybsdata")
	public ResponseEntity<Page<WFStepDataDTO>> fetchByBsdata(WFStepDataSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFStepDataDTO> list = new ArrayList<WFStepDataDTO>();
        
        Page<WFStepData> domains = wfstepdataService.searchByBsdata(context) ;
        for(WFStepData wfstepdata : domains.getContent()){
            WFStepDataDTO dto = new WFStepDataDTO();
            dto.fromDO(wfstepdata);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}

	@ApiOperation(value = "获取DEFAULT", tags = {"WFStepData" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfstepdata/fetchdefault")
	public ResponseEntity<Page<WFStepDataDTO>> fetchDefault(WFStepDataSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFStepDataDTO> list = new ArrayList<WFStepDataDTO>();
        
        Page<WFStepData> domains = wfstepdataService.searchDefault(context) ;
        for(WFStepData wfstepdata : domains.getContent()){
            WFStepDataDTO dto = new WFStepDataDTO();
            dto.fromDO(wfstepdata);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
