package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.WFStepDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.WFStep;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWFStepService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WFStepSearchContext;

@Api(tags = {"WFStep" })
@RestController
@RequestMapping("")
public class WFStepResource {

    @Autowired
    private IWFStepService wfstepService;

    public IWFStepService getWfstepService() {
        return this.wfstepService;
    }

    @ApiOperation(value = "GetDraft", tags = {"WFStep" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfsteps/{wfstep_id}/getdraft")
    @Transactional
    public ResponseEntity<WFStepDTO> getDraft(@PathVariable("wfstep_id") String wfstep_id, @RequestBody WFStepDTO wfstepdto) {
        WFStep wfstep = wfstepdto.toDO();
    	wfstep = wfstepService.getDraft(wfstep) ;
    	wfstepdto.fromDO(wfstep);
        return ResponseEntity.status(HttpStatus.OK).body(wfstepdto);
    }

    @ApiOperation(value = "Create", tags = {"WFStep" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfsteps")
    @Transactional
    public ResponseEntity<WFStepDTO> create(@RequestBody WFStepDTO wfstepdto) {
        WFStepDTO dto = new WFStepDTO();
        WFStep domain = wfstepdto.toDO();
		wfstepService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"WFStep" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfsteps/{wfstep_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody WFStepDTO wfstepdto) {
        WFStep wfstep = wfstepdto.toDO();
    	Boolean b = wfstepService.save(wfstep) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "CheckKey", tags = {"WFStep" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfsteps/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFStepDTO wfstepdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Get", tags = {"WFStep" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfsteps/{wfstep_id}")
    public ResponseEntity<WFStepDTO> get(@PathVariable("wfstep_id") String wfstep_id) {
        WFStepDTO dto = new WFStepDTO();
        WFStep domain = wfstepService.get(wfstep_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Update", tags = {"WFStep" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/wfsteps/{wfstep_id}")
    @Transactional
    public ResponseEntity<WFStepDTO> update(@PathVariable("wfstep_id") String wfstep_id, @RequestBody WFStepDTO wfstepdto) {
		WFStep domain = wfstepdto.toDO();
        domain.setWFStepId(wfstep_id);
		wfstepService.update(domain);
		WFStepDTO dto = new WFStepDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"WFStep" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/wfsteps/{wfstep_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("wfstep_id") String wfstep_id) {
        WFStepDTO wfstepdto = new WFStepDTO();
		WFStep domain = new WFStep();
		wfstepdto.setWFStepId(wfstep_id);
		domain.setWFStepId(wfstep_id);
        Boolean rst = wfstepService.remove(domain.getWFStepId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"WFStep" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfsteps/fetchdefault")
	public ResponseEntity<Page<WFStepDTO>> fetchDefault(WFStepSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFStepDTO> list = new ArrayList<WFStepDTO>();
        
        Page<WFStep> domains = wfstepService.searchDefault(context) ;
        for(WFStep wfstep : domains.getContent()){
            WFStepDTO dto = new WFStepDTO();
            dto.fromDO(wfstep);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
