package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.WFUserDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.WFUser;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWFUserService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WFUserSearchContext;

@Api(tags = {"WFUser" })
@RestController
@RequestMapping("")
public class WFUserResource {

    @Autowired
    private IWFUserService wfuserService;

    public IWFUserService getWfuserService() {
        return this.wfuserService;
    }

    @ApiOperation(value = "Update", tags = {"WFUser" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/wfusers/{wfuser_id}")
    @Transactional
    public ResponseEntity<WFUserDTO> update(@PathVariable("wfuser_id") String wfuser_id, @RequestBody WFUserDTO wfuserdto) {
		WFUser domain = wfuserdto.toDO();
        domain.setWFUserId(wfuser_id);
		wfuserService.update(domain);
		WFUserDTO dto = new WFUserDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"WFUser" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/wfusers/{wfuser_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("wfuser_id") String wfuser_id) {
        WFUserDTO wfuserdto = new WFUserDTO();
		WFUser domain = new WFUser();
		wfuserdto.setWFUserId(wfuser_id);
		domain.setWFUserId(wfuser_id);
        Boolean rst = wfuserService.remove(domain.getWFUserId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Save", tags = {"WFUser" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfusers/{wfuser_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody WFUserDTO wfuserdto) {
        WFUser wfuser = wfuserdto.toDO();
    	Boolean b = wfuserService.save(wfuser) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "GetDraft", tags = {"WFUser" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfusers/{wfuser_id}/getdraft")
    @Transactional
    public ResponseEntity<WFUserDTO> getDraft(@PathVariable("wfuser_id") String wfuser_id, @RequestBody WFUserDTO wfuserdto) {
        WFUser wfuser = wfuserdto.toDO();
    	wfuser = wfuserService.getDraft(wfuser) ;
    	wfuserdto.fromDO(wfuser);
        return ResponseEntity.status(HttpStatus.OK).body(wfuserdto);
    }

    @ApiOperation(value = "CheckKey", tags = {"WFUser" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfusers/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFUserDTO wfuserdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Create", tags = {"WFUser" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfusers")
    @Transactional
    public ResponseEntity<WFUserDTO> create(@RequestBody WFUserDTO wfuserdto) {
        WFUserDTO dto = new WFUserDTO();
        WFUser domain = wfuserdto.toDO();
		wfuserService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Get", tags = {"WFUser" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfusers/{wfuser_id}")
    public ResponseEntity<WFUserDTO> get(@PathVariable("wfuser_id") String wfuser_id) {
        WFUserDTO dto = new WFUserDTO();
        WFUser domain = wfuserService.get(wfuser_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"WFUser" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfusers/fetchdefault")
	public ResponseEntity<Page<WFUserDTO>> fetchDefault(WFUserSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFUserDTO> list = new ArrayList<WFUserDTO>();
        
        Page<WFUser> domains = wfuserService.searchDefault(context) ;
        for(WFUser wfuser : domains.getContent()){
            WFUserDTO dto = new WFUserDTO();
            dto.fromDO(wfuser);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
