package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.WFWorklistDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.WFWorklist;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWFWorklistService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WFWorklistSearchContext;

@Api(tags = {"WFWorklist" })
@RestController
@RequestMapping("")
public class WFWorklistResource {

    @Autowired
    private IWFWorklistService wfworklistService;

    public IWFWorklistService getWfworklistService() {
        return this.wfworklistService;
    }

    @ApiOperation(value = "CheckKey", tags = {"WFWorklist" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfworklists/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WFWorklistDTO wfworklistdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "GetDraft", tags = {"WFWorklist" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfworklists/{wfworklist_id}/getdraft")
    @Transactional
    public ResponseEntity<WFWorklistDTO> getDraft(@PathVariable("wfworklist_id") String wfworklist_id, @RequestBody WFWorklistDTO wfworklistdto) {
        WFWorklist wfworklist = wfworklistdto.toDO();
    	wfworklist = wfworklistService.getDraft(wfworklist) ;
    	wfworklistdto.fromDO(wfworklist);
        return ResponseEntity.status(HttpStatus.OK).body(wfworklistdto);
    }

    @ApiOperation(value = "Update", tags = {"WFWorklist" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/wfworklists/{wfworklist_id}")
    @Transactional
    public ResponseEntity<WFWorklistDTO> update(@PathVariable("wfworklist_id") String wfworklist_id, @RequestBody WFWorklistDTO wfworklistdto) {
		WFWorklist domain = wfworklistdto.toDO();
        domain.setWFWorklistId(wfworklist_id);
		wfworklistService.update(domain);
		WFWorklistDTO dto = new WFWorklistDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Remove", tags = {"WFWorklist" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/wfworklists/{wfworklist_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("wfworklist_id") String wfworklist_id) {
        WFWorklistDTO wfworklistdto = new WFWorklistDTO();
		WFWorklist domain = new WFWorklist();
		wfworklistdto.setWFWorklistId(wfworklist_id);
		domain.setWFWorklistId(wfworklist_id);
        Boolean rst = wfworklistService.remove(domain.getWFWorklistId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Get", tags = {"WFWorklist" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/wfworklists/{wfworklist_id}")
    public ResponseEntity<WFWorklistDTO> get(@PathVariable("wfworklist_id") String wfworklist_id) {
        WFWorklistDTO dto = new WFWorklistDTO();
        WFWorklist domain = wfworklistService.get(wfworklist_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"WFWorklist" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfworklists/{wfworklist_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody WFWorklistDTO wfworklistdto) {
        WFWorklist wfworklist = wfworklistdto.toDO();
    	Boolean b = wfworklistService.save(wfworklist) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Create", tags = {"WFWorklist" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/wfworklists")
    @Transactional
    public ResponseEntity<WFWorklistDTO> create(@RequestBody WFWorklistDTO wfworklistdto) {
        WFWorklistDTO dto = new WFWorklistDTO();
        WFWorklist domain = wfworklistdto.toDO();
		wfworklistService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"WFWorklist" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfworklists/fetchdefault")
	public ResponseEntity<Page<WFWorklistDTO>> fetchDefault(WFWorklistSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFWorklistDTO> list = new ArrayList<WFWorklistDTO>();
        
        Page<WFWorklist> domains = wfworklistService.searchDefault(context) ;
        for(WFWorklist wfworklist : domains.getContent()){
            WFWorklistDTO dto = new WFWorklistDTO();
            dto.fromDO(wfworklist);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}

	@ApiOperation(value = "获取我的已办查询", tags = {"WFWorklist" } ,notes = "获取我的已办查询")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfworklists/fetchdonetask")
	public ResponseEntity<Page<WFWorklistDTO>> fetchDoneTask(WFWorklistSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFWorklistDTO> list = new ArrayList<WFWorklistDTO>();
        
        Page<WFWorklist> domains = wfworklistService.searchDoneTask(context) ;
        for(WFWorklist wfworklist : domains.getContent()){
            WFWorklistDTO dto = new WFWorklistDTO();
            dto.fromDO(wfworklist);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}

	@ApiOperation(value = "获取我的待办查询", tags = {"WFWorklist" } ,notes = "获取我的待办查询")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/wfworklists/fetchtodotask")
	public ResponseEntity<Page<WFWorklistDTO>> fetchTodoTask(WFWorklistSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WFWorklistDTO> list = new ArrayList<WFWorklistDTO>();
        
        Page<WFWorklist> domains = wfworklistService.searchTodoTask(context) ;
        for(WFWorklist wfworklist : domains.getContent()){
            WFWorklistDTO dto = new WFWorklistDTO();
            dto.fromDO(wfworklist);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
