package cn.ibizlab.r7.runtime.wf.service.wfapi.resource;

import java.sql.Timestamp;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.math.BigInteger;
import java.util.HashMap;
import javax.servlet.ServletRequest;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.cglib.beans.BeanCopier;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.http.ResponseEntity;
import org.springframework.web.bind.annotation.*;
import org.springframework.http.HttpStatus;

import org.springframework.data.domain.Page;
import org.springframework.data.domain.PageImpl;
import org.springframework.data.domain.Pageable;
import org.springframework.util.StringUtils;

import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import io.swagger.annotations.ApiResponse;
import io.swagger.annotations.ApiResponses;

import com.alibaba.fastjson.JSONObject;
import org.springframework.data.domain.PageRequest;
import cn.ibizlab.r7.runtime.wf.service.wfapi.dto.WorkflowDTO;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.domain.Workflow;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.service.IWorkflowService;
import cn.ibizlab.r7.runtime.wf.util.SearchContext;
import cn.ibizlab.r7.runtime.wf.core.r7rt_wf.filter.WorkflowSearchContext;

@Api(tags = {"Workflow" })
@RestController
@RequestMapping("")
public class WorkflowResource {

    @Autowired
    private IWorkflowService workflowService;

    public IWorkflowService getWorkflowService() {
        return this.workflowService;
    }

    @ApiOperation(value = "GetDraft", tags = {"Workflow" },  notes = "GetDraft")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/workflows/{workflow_id}/getdraft")
    @Transactional
    public ResponseEntity<WorkflowDTO> getDraft(@PathVariable("workflow_id") String workflow_id, @RequestBody WorkflowDTO workflowdto) {
        Workflow workflow = workflowdto.toDO();
    	workflow = workflowService.getDraft(workflow) ;
    	workflowdto.fromDO(workflow);
        return ResponseEntity.status(HttpStatus.OK).body(workflowdto);
    }

    @ApiOperation(value = "Create", tags = {"Workflow" },  notes = "Create")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/workflows")
    @Transactional
    public ResponseEntity<WorkflowDTO> create(@RequestBody WorkflowDTO workflowdto) {
        WorkflowDTO dto = new WorkflowDTO();
        Workflow domain = workflowdto.toDO();
		workflowService.create(domain);
        dto.fromDO(domain);
		return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "CheckKey", tags = {"Workflow" },  notes = "CheckKey")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/workflows/checkkey")
    public ResponseEntity<Boolean> checkKey(@RequestBody WorkflowDTO workflowdto) {
        return  ResponseEntity.status(HttpStatus.OK).body(true);
    }

    @ApiOperation(value = "Get", tags = {"Workflow" },  notes = "Get")
	@RequestMapping(method = RequestMethod.GET, value = "/wfapi/workflows/{workflow_id}")
    public ResponseEntity<WorkflowDTO> get(@PathVariable("workflow_id") String workflow_id) {
        WorkflowDTO dto = new WorkflowDTO();
        Workflow domain = workflowService.get(workflow_id);
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

    @ApiOperation(value = "Save", tags = {"Workflow" },  notes = "Save")
	@RequestMapping(method = RequestMethod.POST, value = "/wfapi/workflows/{workflow_id}/save")
    public ResponseEntity<Boolean> save(@RequestBody WorkflowDTO workflowdto) {
        Workflow workflow = workflowdto.toDO();
    	Boolean b = workflowService.save(workflow) ;
        return ResponseEntity.status(HttpStatus.OK).body(b);
    }

    @ApiOperation(value = "Remove", tags = {"Workflow" },  notes = "Remove")
	@RequestMapping(method = RequestMethod.DELETE, value = "/wfapi/workflows/{workflow_id}")
    @Transactional
    public ResponseEntity<Boolean> remove(@PathVariable("workflow_id") String workflow_id) {
        WorkflowDTO workflowdto = new WorkflowDTO();
		Workflow domain = new Workflow();
		workflowdto.setWorkflowId(workflow_id);
		domain.setWorkflowId(workflow_id);
        Boolean rst = workflowService.remove(domain.getWorkflowId());
        if(rst){
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}else{
			return ResponseEntity.status(HttpStatus.OK).body(rst);
		}
    }

    @ApiOperation(value = "Update", tags = {"Workflow" },  notes = "Update")
	@RequestMapping(method = RequestMethod.PUT, value = "/wfapi/workflows/{workflow_id}")
    @Transactional
    public ResponseEntity<WorkflowDTO> update(@PathVariable("workflow_id") String workflow_id, @RequestBody WorkflowDTO workflowdto) {
		Workflow domain = workflowdto.toDO();
        domain.setWorkflowId(workflow_id);
		workflowService.update(domain);
		WorkflowDTO dto = new WorkflowDTO();
		dto.fromDO(domain);
        return ResponseEntity.status(HttpStatus.OK).body(dto);
    }

	@ApiOperation(value = "获取DEFAULT", tags = {"Workflow" } ,notes = "获取DEFAULT")
    @RequestMapping(method= RequestMethod.GET , value="/wfapi/workflows/fetchdefault")
	public ResponseEntity<Page<WorkflowDTO>> fetchDefault(WorkflowSearchContext context,Pageable pageable ,ServletRequest request) {
        context.setPageable(pageable);
        List<WorkflowDTO> list = new ArrayList<WorkflowDTO>();
        
        Page<Workflow> domains = workflowService.searchDefault(context) ;
        for(Workflow workflow : domains.getContent()){
            WorkflowDTO dto = new WorkflowDTO();
            dto.fromDO(workflow);
            list.add(dto);
        }
	    return ResponseEntity.status(HttpStatus.OK).body(new PageImpl(list,context.getPageable(),domains.getTotalElements()));
	}


}
